@@ -23,9 +23,9 @@ class ldmArg:
     def __init__(self,sUsage=None,sVer='',iVerbose=0):
         """constructor of argument container
 
-        ### parameter
-            sUsage  ... help string
-            sVer    ... version number
+        Args:
+            sUsage (str): help string
+            sVer (str): version number
         """
         self.lArg=[]
         self.dArg={}
@@ -42,12 +42,13 @@ class ldmArg:
             self.iMode=0
         self.__initDftArg__()
     def __initDftArg__(self):
-        """
-        ### parameter
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        """initialize default arguments
+        
+        Returns:
+            int: return code
+                - >0  ... okay processing done
+                - =0  ... okay nop
+                - <0  ... error
         """
         try:
             # +++++ beg:
@@ -79,30 +80,35 @@ class ldmArg:
         For example sVar sCfgFN specify string argument --cfgFN,
         a file name browser shall be used as GUI control.
 
-        ### parameter
-            sVar    ... option name
+        Args:
+            sVar (str): option name
                 first letter define type
                     i   ... int
                     r   ... float
                     s   ... string
+                
                 following letters build argument
+
                 suffix define GUI control
                     FN  ... file name browser
                     DN  ... directory name browser
                     Chc ... choice
                     Int ... integer
                     Num ... numerical
-            sDft    ... default value
-            sHlp    ... help string
-            sMeta   ... variable example
-            sVerbose .. verbose label
+                
+            sDft (str): default value
+            sHlp (str): help string
+            sMeta (str): variable example
+            sVerbose (str): verbose label
                 if set, shown automatically if verbose activated
-            funcVld ... validation function (callable)
-            kwargs  ... keyword arguments passed to funcVld
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+            funcVld (str): validation function (callable)
+            **kwargs: keyword arguments passed to funcVld
+        
+        Returns:
+            int: return code
+                - >0  ... okay processing done
+                - =0  ... okay nop
+                - <0  ... error
         """
         try:
             # +++++ beg:initialize
@@ -156,13 +162,16 @@ class ldmArg:
             traceback.print_exc()
             return -1
     def prcParse(self,args):
-        """
-        ### parameter
+        """process parse
+
+        Args:
             args    ... tuple of command line arguments
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        
+        Returns:
+            int: return code
+                - >0  ... okay processing done
+                - =0  ... okay nop
+                - <0  ... error
         """
         try:
             # +++++ beg:
@@ -227,12 +236,17 @@ class ldmArg:
             #traceback.print_exc()
             return -1
     def __initPan__(self,oPar,wNb):
-        """
-        ### parameter
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        """initialise panel
+
+        Args:
+            oPar (widget): parent widget
+            wNb (widget): notebook
+        
+        Returns:
+            int: return code
+                - >0  ... okay processing done
+                - =0  ... okay nop
+                - <0  ... error
         """
         try:
             # +++++ beg:
@@ -317,11 +331,15 @@ class ldmArg:
             return -1
     def GetVerbose(self,iVerbose=-1):
         """get verbose level 
-        ### parameter
-        ### return
-            True    ... object verbose >= iVerbose
-            False   ... object verbose < iVerbose
-            number  ... object verbose if iVerbose < 0
+        
+        Args:
+            iVerbose (int): verbosity
+
+        Returns:
+            obj: return code
+                - True : object verbose >= iVerbose
+                - False : object verbose < iVerbose
+                - number : object verbose if iVerbose < 0
         """
         if iVerbose>=0:
             if self.iVerbose>=iVerbose:
@@ -332,12 +350,15 @@ class ldmArg:
             return self.iVerbose
     def GetVerboseDbg(self,iVerbose=-1):
         """get verbose level in debugging mode
-        ### parameter
-        ### return
-            True    ... object verbose >= iVerbose
-            False   ... object verbose < iVerbose
-                    ... log level not in debugging
-            number  ... object verbose if iVerbose < 0
+
+        Args:
+            iVerbose (int): verbosity
+
+        Returns:
+            obj: return code
+                - True    : object verbose >= iVerbose
+                - False   : object verbose < iVerbose or log level not in debugging
+                - number  : object verbose if iVerbose < 0
         """
         if self.iIsDbg>0:
             return self.GetVerbose(iVerbose=iVerbose)
