@@ -18,6 +18,20 @@ from six.moves import _thread as sixThd
 from lindworm.logUtil import ldmUtilLog
 
 class ldmGuiNty:
+    """notify class thread safe object can be from algorithm (processing methods),
+    to update GUI widgets at a later time.
+
+    Attributes:
+        sPhase (str): phase name
+        sStatus (str): status name
+        iVal (int): value
+        iMin (int): minimum
+        iMax (int): maximum
+        iSchedule (int): scheduled
+        iStatus (int): status number
+        iChg (int): changed, GUI shall be updated
+
+    """
     def __init__(self,iVal=0,iMin=0,iMax=100):
         self.sPhase=''
         self.sStatus=''
@@ -28,10 +42,7 @@ class ldmGuiNty:
         self.iStatus=0
         self.iChg=1
     def clrSchedule(self):
-        """
-        ### parameter
-        ### return
-            actions scheduled
+        """clear actions scheduled
         """
         self.iSchedule=0
         self.iChg=1
@@ -48,14 +59,29 @@ class ldmGuiNty:
         self.iStatus=-1
         self.iChg=1
     def IsChg(self):
+        """is changed
+        Returns:
+            return code
+                - 1 : changed
+                - 0 : not changed
+        """
         if self.iChg>0:
             self.iChg=0
             return 1
         return 0
     def IsActive(self,iHndFin=1):
         """check notification still active.
-        event handler is supposed to use methode to prevent
+        event handler is supposed to use method to prevent
         unnecessary notifications.
+
+        Args:
+            iHndFin (int, optional): handle as finished
+        
+        Returns:
+            return code
+                - 1 : active
+                - 0 : inactive
+            
         """
         if self.iStatus>=0:
             return 1
@@ -78,16 +104,27 @@ class ldmGuiNty:
         self.iChg=1
     def GetNtyDat(self):
         """get notify data.
+
+        Returns:
+            ldmGuiNtyDat: notify data
+                - obj (ldmGuiNtyDat): if data changed
+                - None : data unchanged
         """
         if self.IsChg():
             oNtyDat=ldmGuiNtyDat(oNty=self)
             return oNtyDat
         return None
     def GetStatusOfs(self):
-        """get string with schedule and status counter formated.
+        """get string with schedule and status counter formatted.
         schedule 2 digits,
         status 6 digits, or 'fin   ' in case iStatus==-2
         counter overflow is handled here.
+
+        Returns:
+            str: formatted status offset
+                - 'xx.done', if iStatus == -1
+                - 'xx.fin', if iStatus == -2
+                - 'xx.yy', first 2 digits number of schedules, next 2 digits status
         """
         if self.iSchedule>99:
             self.iSchedule=0
@@ -100,38 +137,42 @@ class ldmGuiNty:
         return '%02d.%06d'%(self.iSchedule,self.iStatus)
     def SetPhase(self,sPhase):
         """set phase
-        ### parameter
-            sPhase      ... phase : string
+        
+        Args:
+            sPhase (str): phase
         """
         if sPhase!=self.sPhase:
             self.iChg=1
         self.sPhase=sPhase
     def GetPhase(self):
         """get phase
-        ### return
-            sPhase      ... phase : string
+        
+        Returns:
+            sPhase (str): phase
         """
         return self.sPhase
     def SetStatus(self,sStatus):
         """set sStatus
-        ### parameter
-            sStatus     ... status : string
+        
+        Args:
+            sStatus (str): status
         """
         if self.sStatus!=sStatus:
             self.iChg=1
         self.sStatus=sStatus
     def GetStatus(self):
         """get sStatus
-        ### return
-            sStatus     ... status : string
+        Returns:
+            str: status
         """
         return self.sStatus
     def SetVal(self,iVal,iMin=None,iMax=None):
         """set value
-        ### parameter
-            iVal    ... value : int
-            iMin    ... minimum : int
-            iMax    ... maximum : int
+        
+        Args:
+            iVal (int): value
+            iMin (int): minimum
+            iMax (int): maximum
         """
         if iMin is not None:
             self.iMin=iMin
@@ -146,26 +187,30 @@ class ldmGuiNty:
         self.iVal=iVal
     def SetMin(self,iMin):
         """set minimum
-        ### parameter
-            iMin    ... minimum : int
+        
+        Args:
+            iMin (int): minimum
         """
         if self.iMin!=Min:
             self.iChg=1
         self.iMin=iMin
     def SetMax(self,iMax):
         """set maximum
-        ### parameter
-            iMax    ... maximum : int
+        
+        Args:
+            iMax (int): maximum
         """
         if self.iMax!=iMax:
             self.iChg=1
         self.iMax=iMax
     def GetNormalized(self,rScale=1000):
         """get normalized value scaled between 0 to rScale.
-        ### parameter
-            rScale  ... scale limit
-        ### return
-            rVal    ... normalized value (min/max),
+        
+        Args:
+            rScale (float): scale limit
+        
+        Returns:
+            float: rVal, normalized value (min/max),
                         0 <= rVal <= rScale
         """
         try:
@@ -179,7 +224,20 @@ class ldmGuiNty:
             return 12
 
 class ldmGuiNtyDat:
+    """
+
+    Attributes:
+        sPhase (str): phase name
+        sStatus (str): status name
+        sStatusOfs (str): status offset
+        iValNormalized (int): normalized value
+    """
     def __init__(self,oNty=None):
+        """constructor
+
+        Args:
+            oNty (obj, optional): notify object
+        """
         if oNty is None:
             self.sPhase=''
             self.sStatus=''
@@ -192,27 +250,32 @@ class ldmGuiNtyDat:
             self.iValNormalized=oNty.GetNormalized()
     def GetPhase(self):
         """get phase
-        ### return
-            sPhase      ... phase : string
+        
+        Returns:
+            sPhase (str) phase
         """
         return self.sPhase
     def GetStatus(self):
         """get sStatus
-        ### return
-            sStatus     ... status : string
+        Returns:
+            str: status (sStatus)
         """
         return self.sStatus
     def GetStatusOfs(self):
-        """get string with schedule and status counter formated.
+        """get string with schedule and status counter formatted.
         schedule 2 digits,
         status 6 digits, or 'fin   ' in case iStatus==-2
         counter overflow is handled here.
+
+        Returns:
+            str: status offset (sStatusOfs)
         """
         return self.sStatusOfs
     def GetNormalized(self):
         """get normalized value scaled between 0 to 1000.
-        ### return
-            rVal    ... normalized value (min/max),
+        
+        Returns:
+            int: rVal, normalized value (min/max),
                         0 <= rVal <= 1000
         """
         return self.iValNormalized
