@@ -24,14 +24,16 @@ from lindworm.ldmGuiNty import ldmGuiNty
 # ----- end:initialize
 
 class ldmGuiThd(ldmUtilLog):
+    """GUI thread
+    """
     def __init__(self,oGui,rDly=0.200,sLogger='ldmGuiThd',iLv=0,iVerbose=0):
         """constructor
-        ### parameter
-            oGui        ... GUI object
-            rDly        ... delay between processing [s], yield GIL
-            sLogger     ... log origin
-            iLv         ... log level short
-            iVerbose    ... higher values add more logs
+        Args:
+            oGui (widget): GUI object
+            rDly (float , optional): delay between processing [s], yield GIL
+            sLogger (str , optional): log origin
+            iLv (int , optional): log level short
+            iVerbose (int , optional): higher values add more logs
         """
         ldmUtilLog.__init__(self,sLogger=sLogger,iLv=iLv,
                             iVerbose=iVerbose)
@@ -43,11 +45,15 @@ class ldmGuiThd(ldmUtilLog):
         self.oNty=ldmGuiNty()
     def BindEvtNty(self,funcOnNty):
         """bind event function to oGui object
-        ### parameter
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+
+        Args:
+            funcOnNty function to bind
+        
+        Returns:
+            return code
+                - >0 : okay
+                - =0 : okay nop
+                - <0 : error
         """
         try:
             if self.oGui is not None:
@@ -60,23 +66,27 @@ class ldmGuiThd(ldmUtilLog):
             return -1
     def GetNty(self):
         """get notify object
-        ### parameter
-        ### return
-            !=None  ... okay processing done
-            ==None  ... okay nop
+        
+        Returns:
+            obj: notify object
+                - !=None : okay processing done
+                - ==None : okay nop
         """
         return self.oNty
     def Do(self,sPhase,func,*args,**kwargs):
         """schedule callable
-        ### parameter
-            sPhase  ... phase name
-            fun     ... callable
-            args    ... argument
-            kwargs  ... keyword arguments
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        
+        Args:
+            sPhase (str): phase name
+            fun (callable): callable
+            args (list): argument
+            kwargs (dict): keyword arguments
+        
+        Returns:
+            return code
+                - >0 : okay
+                - =0 : okay nop
+                - <0 : error
         """
         try:
             # +++++ beg:
@@ -105,20 +115,25 @@ class ldmGuiThd(ldmUtilLog):
             self.logTB()
             return -1
     def Start(self):
+        """start thread
+        """
         self.iKeepRun=1
         self.iRunning=1
         self.iRunExc=1
         sixThd.start_new_thread(self._runNotify,())
         sixThd.start_new_thread(self._runExc,())
     def Stop(self):
+        """signal thread stop
+        """
         self.iKeepRun=0
     def _runNotify(self):
         """
-        ### parameter
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        
+        Returns:
+            return code
+                - >0 : okay processing
+                - =0 : okay nop
+                - <0 : error
         """
         try:
             # +++++ beg:
@@ -165,17 +180,23 @@ class ldmGuiThd(ldmUtilLog):
             self.logTB()
             return -1
     def delay(self,iCnt=1):
+        """delay, be a gentle thread
+
+        Args:
+            iCnt (int): count of additional rDly sleeps
+        """
         time.sleep(self.rDly)
         while iCnt>0:
             time.sleep(self.rDly)
             iCnt-=1
     def _runExc(self):
-        """
-        ### parameter
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        """thread loop
+        
+        Returns:
+            return code:
+                - >0 : okay processing
+                - =0 : okay nop
+                - <0 : error
         """
         try:
             # +++++ beg:
@@ -211,11 +232,13 @@ class ldmGuiThd(ldmUtilLog):
             return -1
     def __tpl(self):
         """
-        ### parameter
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        Args:
+
+        Returns:
+            return code
+                - >0 : okay 
+                - =0 : okay nop
+                - <0 : error
         """
         try:
             # +++++ beg:
