@@ -18,17 +18,23 @@ from lindworm.ldmStorageLine import ldmStorageLine
 from lindworm.ldmStr import ldmStr
 
 class ldmMD(ldmStorageLine):
+    """markdown processing
+    read file and follow references one to build a 
+    single result more consistent and easy to convert by pandoc
+    into different format.
+    Referenced images are copied to a single folder also to
+    benefit pandoc post processing.
+    """
     SEP_HDR='.'
     def __init__(self,sFN,sLogger='',iLv=1,
                  iSkipDN=-1,iVerbose=0):
         """constructor
-        ### parameter
-            iModeRev    ... reverse processing
-                    1   ... FILO, first in last out
-                    0   ... FIFO, first in first out
-            sLogger     ... log origin
-            iLv         ... logging level
-            iVerbose    ... higher values add more logs
+        
+        Args:
+            sFN (str): file name
+            sLogger (str , optional): log origin
+            iLv (int , optional): logging level
+            iVerbose (int , optional): higher values add more logs
         """
         ldmStorageLine.__init__(self,
                     iModeRev=0,
@@ -66,12 +72,17 @@ class ldmMD(ldmStorageLine):
     #    self.__initDat__()
     def getHdrNavLv(self,iOfs=0):
         """get header level, maximal 6 allowed
-        ### parameter
-            iOfs    ... offset to header
-        ### return
-            sNav    ... navigation data
-            sHdr    ... header
-            iLv     ... level, 1 to 6, -1= out of range
+        
+        Args:
+            iOfs (int , optional): offset to header
+        
+        Returns:
+            tuple
+                sNav (str): navigation data
+
+                sHdr (str): header
+
+                iLv (int): level, 1 to 6, -1= out of range
         """
         try:
             if len(self.lHdrNavLv)>iOfs:
@@ -82,10 +93,12 @@ class ldmMD(ldmStorageLine):
             return '','',-1
     def getHdrLv(self,sLine):
         """get header level, maximal 6 allowed
-        ### return
-            >0  ... okay header found
-            =0  ... okay nop
-            <0  ... error
+        
+        Returns:
+            return code
+                - >0 : okay header found
+                - =0 : okay nop
+                - <0 : error
         """
         try:
             sTmp=sLine.strip()
@@ -99,12 +112,14 @@ class ldmMD(ldmStorageLine):
             return -1
     def bldDat(self,sDef,oRef=None,**kwargs):
         """check definition has been queues/processed already  
-        ### parameter
-            sDef    ... definition to check
-            oRef    ... reference object
-            kwargs  ... flexible keyword argument
-        ### return
-            oDat    ... okay marked for processing done
+        
+        Args:
+            sDef (str): definition to check
+            oRef (obj , optional): reference object
+            kwargs (dict): flexible keyword argument
+        
+        Returns:
+            obj : oDat , okay marked for processing done
         """
         try:
             sOrg='ldmMD::bldDat'
@@ -119,12 +134,15 @@ class ldmMD(ldmStorageLine):
             return None
     def handleLink(self,sLink,oGtrMD=None):
         """handle link
-        ### parameter
-            sLink   ... link data
-            oGtrMD  ... global storage
-        ### return
-            ''      ... changed string
-            None    ... error
+        
+        Args:
+            sLink (str): link data
+            oGtrMD (obj , optional): global storage
+        
+        Returns:
+            link name
+                - '' (str) c:hanged string
+                - None    ... error
         """
         try:
             # +++++ beg:initialize
@@ -186,10 +204,11 @@ class ldmMD(ldmStorageLine):
             return None
     def getHdrPrefix(self):
         """get header prefix, reflect origin
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        
+        Returns:
+            str: header prefix
+                - header prefix
+                - '' : error
         """
         try:
             # +++++ beg:find file extension
@@ -210,12 +229,14 @@ class ldmMD(ldmStorageLine):
             return ''
     def getHdrIdf(self,sHdr):
         """get header path as string separated by SEP_HDR
-        ### parameter
-            sHdr    ... header
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        
+        Args:
+            sHdr (str): header
+        
+        Returns:
+            str: header identifier
+                - header identifier string
+                - '' : error
         """
         try:
             # +++++ beg:initialize
@@ -241,13 +262,16 @@ class ldmMD(ldmStorageLine):
             return ''
     def setHdr(self,iHdr,sHdr):
         """store heading at proper header location
-        ### parameter
-            iHdr    ... header level
-            sHdr    ... header
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        
+        Args:
+            iHdr (int): header level
+            sHdr (str): header
+        
+        Returns:
+            return code
+                - >0 : okay processing done
+                - =0 : okay nop
+                - <0 : error
         """
         try:
             # +++++ beg:initialize
@@ -279,15 +303,18 @@ class ldmMD(ldmStorageLine):
             return -1
     def prcLine(self,iLine,sLine,**kwargs):
         """add line to storage
-        ### parameter
-            iLine   ... line number : int
-            sLine   ... line : str
-            oGtrMD   ... gather object
-            **kwargs ... flexible keyword argument
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        
+        Args:
+            iLine (int): line number
+            sLine (str): line
+            oGtrMD (obj): gather object
+            **kwargs (dict): flexible keyword argument
+        
+        Returns:
+            return code
+                - >0 : okay processing done
+                - =0 : okay nop
+                - <0 : error
         """
         try:
             # +++++ beg:initialize
@@ -488,12 +515,14 @@ class ldmMD(ldmStorageLine):
             return -1,sLine
     def prcExc(self,**kwargs):
         """processing execution
-        ### parameter
-            **kwargs ... flexible keyword argument
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        
+        Args:
+            kwargs (dict): flexible keyword argument
+        
+        Returns:
+            - >0 : okay processing done
+            - =0 : okay nop
+            - <0 : error
         """
         try:
             # +++++ beg:initialize
