@@ -20,15 +20,18 @@ from lindworm.logUtil import ldmUtilLog
 import lindworm.ldmOS as ldmOS
 
 class ldmStorage(ldmUtilLog):
+    """storage base class
+    """
     def __init__(self,iModeRev=0,sLogger='',iLv=1,iVerbose=0):
         """constructor
-        ### parameter
-            iModeRev    ... reverse processing
-                    1   ... FILO, first in last out
-                    0   ... FIFO, first in first out
-            sLogger     ... log origin
-            iLv         ... log level short
-            iVerbose    ... higher values add more logs
+        
+        Args:
+            iModeRev (int , optional): reverse processing
+                    - 1 : FILO, first in last out
+                    - 0 : FIFO, first in first out
+            sLogger (str , optional): log origin
+            iLv (int , optional): logging level
+            iVerbose (int , optional): higher values add more logs
         """
         ldmUtilLog.__init__(self,sLogger=sLogger,iLv=iLv,
                             iVerbose=iVerbose)
@@ -119,6 +122,9 @@ class ldmStorage(ldmUtilLog):
         self.__initPrc__()
     def clrDef(self):
         """clear stored file names to process
+
+        Returns:
+            int: size of definition list lDef
         """
         iRet=len(self.lDef)
         self.lDef=[]
@@ -129,6 +135,13 @@ class ldmStorage(ldmUtilLog):
         self.__initDat__()
     def clrEnd(self):
         """clear stored file names to process
+
+        Returns:
+            return code
+                - >0 : okay 
+                - =0 : okay nop
+                - <0 : error
+
         """
         self.sDefEnd=None
         self.oArgEnd=None
@@ -137,8 +150,11 @@ class ldmStorage(ldmUtilLog):
         return 1
     def getLstDef(self):
         """get definition list
-        ### return
-            []  ... list of definition stored
+        
+        Returns:
+            list: list of definition stored
+                - list
+                - [] : error
         """
         try:
             return self.lDef
@@ -147,12 +163,15 @@ class ldmStorage(ldmUtilLog):
             return []
     def getDef(self):
         """get current file name
-        ### return
-            iRet    ... return code
-                >0  ... okay processing done
-                =0  ... okay nop
-                <0  ... error
-            sFN     ... file name : str
+        
+        Returns:
+            tuple
+                return code
+                    - >0 : okay processing done
+                    - =0 : okay nop
+                    - <0 : error
+
+                sFN     ... file name : str
         """
         try:
             if len(self.lDef)>0:
@@ -167,12 +186,15 @@ class ldmStorage(ldmUtilLog):
             return -1,None
     def getDat(self,sDef=None):
         """current data object
-        ### parameter
-            sDef    ... definition to search, None = get current reference
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        
+        Args:
+            sDef (str , optional): definition to search, None = get current reference
+        
+        Returns:
+            return code
+                - >0 : okay processing done
+                - =0 : okay nop
+                - <0 : error
         """
         try:
             if sDef is None:
@@ -189,12 +211,15 @@ class ldmStorage(ldmUtilLog):
             return -1,None
     def getRef(self,sDef=None):
         """get current reference object
-        ### parameter
-            sDef    ... definition to search, None = get current reference
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        
+        Args:
+            sDef (str , optional): definition to search, None = get current reference
+        
+        Returns:
+            return code
+                - >0 : okay processing done
+                - =0 : okay nop
+                - <0 : error
         """
         try:
             if sDef is None:
@@ -211,12 +236,15 @@ class ldmStorage(ldmUtilLog):
             return -1,None
     def prcIsDone(self,sDef):
         """check definition has been queues/processed already  
-        ### parameter
-            sDef ... definition to check
-        ### return
-            >0  ... okay marked for processing done
-            =0  ... okay unknown file name
-            <0  ... error
+        
+        Args:
+            sDef (str , optional): definition to check
+        
+        Returns:
+            return code
+                - >0 : okay marked for processing done
+                - =0 : okay unknown file name
+                - <0 : error
         """
         try:
             if sDef in self.dDat:
@@ -231,12 +259,16 @@ class ldmStorage(ldmUtilLog):
             return -1
     def bldDat(self,sDef,oRef=None,**kwargs):
         """check definition has been queues/processed already  
-        ### parameter
-            sDef    ... definition to check
-            oRef    ... reference object
-            kwargs  ... flexible keyword argument
-        ### return
-            oDat    ... okay marked for processing done
+        
+        Args:
+            sDef (str): definition to check
+            oRef (obj , optional): reference object
+            kwargs (dict): flexible keyword argument
+        
+        Returns:
+            dict: okay marked for processing done
+                - dict
+                - None : error
         """
         try:
             sOrg='ldmStorage::bldDat'
@@ -249,16 +281,19 @@ class ldmStorage(ldmUtilLog):
             self.logTB()
             return None
     def prcBeg(self,sDef,oRef=None,**kwargs):
-        """processing begin, add file name and objects to stack
-        ### parameter
-            sDef    ... definition name : str
-            oDat    ... data object
-            oRef    ... reference object
-            kwargs  ... flexible keyword argument
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        """processing begin, add definition and objects to stack
+        
+        Args:
+            sDef (str): definition name : str
+            oDat (obj): data object
+            oRef (obj): reference object
+            kwargs (dict): flexible keyword argument
+        
+        Returns:
+            return code
+                - >0 : okay processing done
+                - =0 : okay nop
+                - <0 : error
         """
         try:
             # +++++ beg:initialize
@@ -284,12 +319,15 @@ class ldmStorage(ldmUtilLog):
             return -1
     def prcExc(self,**kwargs):
         """processing end
-        ### parameter
-            kwargs  ... flexible keyword argument
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        
+        Args:
+            kwargs (dict): flexible keyword argument
+        
+        Returns:
+            return code
+                - >0 : okay processing done
+                - =0 : okay nop
+                - <0 : error
         """
         try:
             # +++++ beg:initialize
@@ -311,16 +349,22 @@ class ldmStorage(ldmUtilLog):
             return -1
     def prcEnd(self,**kwargs):
         """processing end
-        ### parameter
-            **kwargs ... flexible keyword argument
-        ### return
-            iRet    ... return code
-                >0  ... okay processing done
-                =0  ... okay nop
-                <0  ... error
-            sFN     ... filename
-            oDat    ... data object
-            oRef    ... reference object
+        
+        Args:
+            kwargs (dict): flexible keyword argument
+        
+        Returns:
+            tuple
+                return code
+                    - >0 : okay processing done
+                    - =0 : okay nop
+                    - <0 : error
+
+                sFN (str): filename
+
+                oDat (obj): data object
+                
+                oRef (obj): reference object
         """
         try:
             # +++++ beg:initialize
@@ -346,14 +390,18 @@ class ldmStorage(ldmUtilLog):
             return -1
     def saveJson(self,oDat,sFN,sDN=None,sSfx=None):
         """write object attribute data to json file
-        ### parameter
-            sFN     ... file name
-            sDN     ... directory
-            sSfx    ... suffix
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        
+        Args:
+            oDat (obj): data object
+            sFN (str): file name
+            sDN (str , optional): directory
+            sSfx (str , optional): suffix
+        
+        Returns:
+            return code
+                - >0 : okay processing done
+                - =0 : okay nop
+                - <0 : error
         """
         try:
             # +++++ beg:initialize
@@ -384,16 +432,19 @@ class ldmStorage(ldmUtilLog):
             return -1
     def loadJson(self,dDat,sK,sFN,sDN=None,iUpdate=0):
         """load directory list to json
-        ### parameter
-            dDat    ... dictionary
-            sK      ... key to place loaded data
-            sFN     ... file name
-            sDN     ... optional directory
-            iUpdate ... update dDat[sK]
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        
+        Args:
+            dDat (dict): dictionary
+            sK (str): key to place loaded data
+            sFN (str): file name
+            sDN (str , optional): optional directory
+            iUpdate (int , optional): update dDat[sK]
+        
+        Returns:
+            return code
+                - >0 : okay processing done
+                - =0 : okay nop
+                - <0 : error
         """
         try:
             # +++++ beg:build input file name
@@ -427,14 +478,17 @@ class ldmStorage(ldmUtilLog):
             return -1
     def saveAtr(self,sFN,sDN=None,lAtr=None):
         """save object attribute data to json file
-        ### parameter
-            sFN     ... file name
-            sDN     ... directory
-            lAtr    ... attribute list
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        
+        Args:
+            sFN (str): file name
+            sDN (str , optional): directory
+            lAtr (list , optional): attribute list
+        
+        Returns:
+            return code
+                - >0 : okay processing done
+                - =0 : okay nop
+                - <0 : error
         """
         try:
             # +++++ beg:initialize
@@ -464,14 +518,18 @@ class ldmStorage(ldmUtilLog):
             return -1
     def saveDat(self,sFN,sDN=None,lKey=None,sAtr='dDat'):
         """save object data to json file
-        ### parameter
-            sFN     ... file name
-            sDN     ... directory
-            lKey    ... keys
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        
+        Args:
+            sFN (str): file name
+            sDN (str , optional): directory
+            lKey (list , optional) keys
+            sAtr (str , optional): attribute
+        
+        Returns:
+            return code
+                - >0 : okay processing done
+                - =0 : okay nop
+                - <0 : error
         """
         try:
             # +++++ beg:initialize
@@ -513,14 +571,18 @@ class ldmStorage(ldmUtilLog):
             return -1
     def loadDat(self,sFN,sDN=None,sKey=None,sAtr='dDat'):
         """load object data to json file
-        ### parameter
-            sFN     ... file name
-            sDN     ... directory
-            lKey    ... keys
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        
+        Args:
+            sFN (str): file name
+            sDN (str , optional): directory
+            lKey (list , optional): keys
+            sAtr (str , optional): attribute
+
+        Returns:
+            return code
+                - >0 : okay processing done
+                - =0 : okay nop
+                - <0 : error
         """
         try:
             # +++++ beg:initialize
@@ -560,16 +622,20 @@ class ldmStorage(ldmUtilLog):
             return -1
     def getCfg(self,sKey,sType=None,oDft=None):
         """get configuration value
-        ### parameter
-            sKey    ... configuration key
-            sType   ... type enforcement
-            oDft    ... default value
-        ### return
-            return code
-                >0  ... okay processing done
-                =0  ... okay nop
-                <0  ... error
-            value
+        
+        Args:
+            sKey (str): configuration key
+            sType (str , optional): type enforcement
+            oDft (obj , optional) default value
+        
+        Returns:
+            tuple
+                return code
+                    - >0 : okay processing done
+                    - =0 : okay nop
+                    - <0 : error
+                
+                value
         """
         try:
             # +++++ beg:initialize
@@ -605,12 +671,15 @@ class ldmStorage(ldmUtilLog):
             return -1,None
     def loadCfg(self,sCfgFN='cfg.json'):
         """read configuration file, given in json format
-        ### parameter
-            sCfgDN  ... configuration file name
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        
+        Args:
+            sCfgDN (str , optional): configuration file name
+        
+        Returns
+            return code
+                - >0 : okay processing done
+                - =0 : okay nop
+                - <0 : error
         """
         try:
             # +++++ beg:initialize
@@ -635,11 +704,13 @@ class ldmStorage(ldmUtilLog):
             return -1
     def __tpl(self):
         """
-        ### parameter
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        Args:
+
+        Returns:
+            return code
+                - >0 : okay processing done
+                - =0 : okay nop
+                - <0 : error
         """
         try:
             # +++++ beg:
