@@ -23,15 +23,18 @@ from lindworm.ldmStorage import ldmStorage
 from lindworm.ldmOS import getSha
 
 class ldmStorageFolder(ldmStorage):
+    """folder storage class
+    """
     def __init__(self,iModeRev=0,sLogger='srgFld',iLv=0,iVerbose=0):
         """constructor
-        ### parameter
-            iModeRev    ... reverse processing
-                    1   ... FILO, first in last out
-                    0   ... FIFO, first in first out
-            sLogger     ... log origin
-            iLv         ... logging level
-            iVerbose    ... higher values add more logs
+        
+        Args:
+            iModeRev (int): reverse processing
+                    - 1 : FILO, first in last out
+                    - 0 : FIFO, first in first out
+            sLogger (str): log origin
+            iLv (int): logging level
+            iVerbose (int): higher values add more logs
         """
         ldmStorage.__init__(self,iModeRev=iModeRev,
                             sLogger=sLogger,iLv=iLv,
@@ -88,17 +91,21 @@ class ldmStorageFolder(ldmStorage):
         return iRet
     def getDatRel(self,sRelDN,sBaseDN=None):
         """get relative content from data
-        ### parameter
-            sRelDN  ... relative DN
-            sBaseDN ... base DN
-        ### return
-            iRet
-                >0  ... okay processing done
-                =0  ... okay nop
-                <0  ... error
-            dDN ... directory content
-                dict  ... {'.':...}
-                None  ... invalid content
+        
+        Args:
+            sRelDN (str): relative DN
+            sBaseDN (str): base DN
+        
+        Returns:
+            tuple
+                - return code
+                    - >0 : okay processing done
+                    - =0 : okay nop
+                    - <0 : error
+
+                - dDN (dict): directory content
+                    - dict : {'.':...}
+                    - None : invalid content
         """
         try:
             # +++++ beg:get relative path list
@@ -125,12 +132,17 @@ class ldmStorageFolder(ldmStorage):
             return -1,None
     def getDatContent(self,sRoot):
         """get content from data
-        ### parameter
-            sRoot   ... directory
-        ### return
-            sCurDN  ... current directory name, relative
-            sDN     ... directory content
-            sFN     ... file content
+        
+        Args:
+            sRoot (str): directory
+        
+        Returns:
+            tuple
+                - sCurDN (str): current directory name, relative
+                
+                - sDN (str): directory content
+                
+                - sFN (str): file content
         """
         try:
             if self.iVerbose>90:
@@ -185,12 +197,14 @@ class ldmStorageFolder(ldmStorage):
             return None,None,None
     def prcBeg(self,sDef,oRef=None,**kwargs):
         """processing begin, add file name and objects to stack
-        ### parameter
-            sSrcDN  ... source directory name : str
-            oDat    ... data object
-            oRef    ... reference object
-            kwargs  ... flexible keyword argument
-        ### return
+        
+        Args:
+            sSrcDN (str): source directory name : str
+            oDat (obj): data object
+            oRef (obj): reference object
+            kwargs : flexible keyword argument
+        
+        Returns:
             >0  ... okay processing done
             =0  ... okay nop
             <0  ... error
@@ -219,12 +233,15 @@ class ldmStorageFolder(ldmStorage):
             return -1
     def prcExc(self,oNty=None,**kwargs):
         """processing execution
-        ### parameter
-            **kwargs ... flexible keyword argument
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        
+        Args:
+            kwargs : flexible keyword argument
+        
+        Returns:
+            return code
+                - >0 : okay processing done
+                - =0 : okay nop
+                - <0 : error
         """
         try:
             # +++++ beg:initialize
@@ -296,18 +313,21 @@ class ldmStorageFolder(ldmStorage):
             return -1
     def prcEnd(self,**kwargs):
         """processing end
-        ### parameter
-            *kwargs ... flexible keyword argument
+
+        use updated properties to access current properties to be finalized
+            - self.sDefEnd : definition
+            - self.oArgEnd : keyword arguments passed at prcBeg
+            - self.oDatEnd : data object
+            - self.oRefEnd : reference object
+
+        Args:
+            kwargs : flexible keyword argument
             
-            use updated properties to access current properties to be finalized
-            self.sDefEnd    ... definition
-            self.oArgEnd    ... keyword arguments passed at prcBeg
-            self.oDatEnd    ... data object
-            self.oRefEnd    ... reference object
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        Returns:
+            return code
+                - >0 : okay processing done
+                - =0 : okay nop
+                - <0 : error
         """
         try:
             # +++++ beg:initialize
@@ -384,13 +404,15 @@ class ldmStorageFolder(ldmStorage):
             return -1
     def prcPost(self,**kwargs):
         """processing end
+
+        Args:
             **kwargs ... flexible keyword argument
                 iShaMB  ... data to calculate sha in MB 
-        ### return
-            iRet    ... return code
-                >0  ... okay processing done
-                =0  ... okay nop
-                <0  ... error
+        Returns:
+            return code
+                - >0 : okay processing done
+                - =0 : okay nop
+                - <0 : error
         """
         try:
             # +++++ beg:initialize
@@ -594,6 +616,7 @@ def main(args=None):
     print('\nend processing')
     print('   iRet:%r'%(iRet))
     # ----- end:finished
+    return iRet
 
 if __name__=='__main__':
     # +++++ beg:call entry point
