@@ -19,10 +19,17 @@ import wx
 
 from lindworm.logUtil import ldmUtilLog
 from lindworm.ldmWidCoreEvt import ldmWidCoreEvt
+from lindworm.ldmGuiThd import ldmGuiThd
 
 gdCtrlId={}
 
 def ldmWidCoreCtrlId(sKey,sSub=None):
+    """widget control ID
+
+    Args:
+        sKey (str): widget name
+        sSub (str): widget sub name
+    """
     try:
         global gdCtrlId
         if sKey in gdCtrlId:
@@ -41,35 +48,43 @@ def ldmWidCoreCtrlId(sKey,sSub=None):
         return wx.NewIdRef()
 
 def ldmWidCoreGetIcon(bmp):
+    """get icon
+    """
     icon = wx.EmptyIcon()
     icon.CopyFromBitmap(bmp)
     return icon
 
 class ldmWidCore(ldmUtilLog,ldmWidCoreEvt):
+    """core widget class, all widget should be derived from it.
+    common interface is established to remove burden to use IDE
+    to create widgets. Simple lists without to deep knowledge about
+    underlying GUI library, currently wxPython is required to create
+    a fully featured GUI.
+    """
     def __init__(self,sLogger='',iLv=1,iVerbose=0,sCfgFN=None,**kwargs):
         """constructor
-        several sub constructor methods are called
+        several sub constructor methods are called in that order
         
-        + __initCls__: initialize class
-        + __initCfg__: initialize object configuration
-        + __initDat__: initialize internal data
-        + __initObj__: initialize object data
-        + __initWid__: initialize widget
-        + __initEvt__: initialize widget event
-        + __initPrp__: initialize properties, widget data
+            - __initCls__: initialize class
+            - __initCfg__: initialize object configuration
+            - __initDat__: initialize internal data
+            - __initObj__: initialize object data
+            - __initWid__: initialize widget
+            - __initEvt__: initialize widget event
+            - __initPrp__: initialize properties, widget data
         
-        ### parameter
-            sLogger ... log origin
-            iLv         ... trivial logging level
-                0       ... debug
-                1       ... info
-                2       ... warning
-                3       ... error
-                4       ... critical
-                x       ... debug
-            iVerbose    ... higher values add more logs
-            sCfgFN  ... json configuration file
-            kwargs  ... keyword arguments passed to all init methods
+        Args:
+            sLogger (str , optional): log origin
+            iLv (int , optional): logging level
+                - 0       ... debug
+                - 1       ... info
+                - 2       ... warning
+                - 3       ... error
+                - 4       ... critical
+                - x       ... debug
+            iVerbose (int , optional): higher values add more logs
+            sCfgFN (str , optional) json configuration file
+            kwargs (dict): keyword arguments passed to all init methods
         """
         ldmUtilLog.__init__(self,sLogger,iLv=iLv,
                     iVerbose=iVerbose)
@@ -94,14 +109,18 @@ class ldmWidCore(ldmUtilLog,ldmWidCoreEvt):
             self.logTB()
     def __initCls__(self,**kwargs):
         """initialize class
-        ### parameter
-            kwargs  ... keyword arguments passed to all init methods
+        
+        Args:
+            kwargs (dict): keyword arguments passed to all init methods
         """
         self.clsWid=None
     def __initCfg__(self,**kwargs):
         """initialize configuration
-        ### parameter
-            kwargs  ... keyword arguments passed to all init methods
+        setup default values for configurable properties in self.dCfgWid
+        or by means of self.setCfgWid
+        
+        Args:
+            kwargs (dict): keyword arguments passed to all init methods
         """
         try:
             # +++++ beg:initialize
@@ -128,8 +147,9 @@ class ldmWidCore(ldmUtilLog,ldmWidCoreEvt):
             self.logTB()
     def __initDat__(self,**kwargs):
         """initialize internal data, intended to application
-        ### parameter
-            kwargs  ... keyword arguments passed to all init methods
+        
+        Args:
+            kwargs (dict): keyword arguments passed to all init methods
         """
         try:
             # +++++ beg:initialize
@@ -147,8 +167,9 @@ class ldmWidCore(ldmUtilLog,ldmWidCoreEvt):
         """initialize object properties, widgets aren't present yet.
         data is supposed to be related to widgets or support their
         function.
-        ### parameter
-            kwargs  ... keyword arguments passed to all init methods
+        
+        Args:
+            kwargs (dict): keyword arguments passed to all init methods
         """
         try:
             # +++++ beg:initialize
@@ -164,8 +185,9 @@ class ldmWidCore(ldmUtilLog,ldmWidCoreEvt):
             self.logTB()
     def __initWid__(self,**kwargs):
         """initialize widgets
-        ### parameter
-            kwargs  ... keyword arguments passed to all init methods
+        
+        Args:
+            kwargs (dict): keyword arguments passed to all init methods
         """
         wid=None
         try:
@@ -183,8 +205,9 @@ class ldmWidCore(ldmUtilLog,ldmWidCoreEvt):
         return wid
     def __initEvt__(self,**kwargs):
         """initialize event handling, widgets are already created
-        ### parameter
-            kwargs  ... keyword arguments passed to all init methods
+        
+        Args:
+            kwargs (dict): keyword arguments passed to all init methods
         """
         try:
             # +++++ beg:initialize
@@ -200,8 +223,9 @@ class ldmWidCore(ldmUtilLog,ldmWidCoreEvt):
             self.logTB()
     def __initLayout__(self,**kwargs):
         """initialize layout
-        ### parameter
-            kwargs  ... keyword arguments passed to all init methods
+        
+        Args:
+            kwargs (dict): keyword arguments passed to all init methods
         """
         try:
             # +++++ beg:initialize
@@ -217,8 +241,12 @@ class ldmWidCore(ldmUtilLog,ldmWidCoreEvt):
             self.logTB()
     def __initPrp__(self,**kwargs):
         """initialize properties, supposed to be related to widgets.
-        ### parameter
-            kwargs  ... keyword arguments passed to all init methods
+        
+        Args:
+            kwargs (dict:) keyword arguments passed to all init methods
+        
+        Returns:
+            wid: widget
         """
         wid=None
         try:
@@ -236,64 +264,55 @@ class ldmWidCore(ldmUtilLog,ldmWidCoreEvt):
         return wid
     def __str__(self):
         """get object string
-        ### parameter
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        
+        Returns:
+            str: object string
         """
         return self.sOrg
     def __repr__(self):
         """get object representation
-        ### parameter
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        
+        Returns:
+            str: representation string
         """
         return self.sOrg
     def GetWid(self):
         """get main widget.
         panel some times.
-        ### parameter
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        
+        Returns:
+            wid: widget
         """
         return self.wid
     def GetWidMod(self):
         """ get widget to indicate modification.
-        ### parameter
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        
+        Returns:
+            wid: widget
         """
         return self.wid
     def GetWidChild(self):
         """future extension
         ### parameter
         ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+            None .. future
         """
         return None
     def GetCacheDict(self,sAttr,bChk=False):
         """get dictionary for caching data,
         create empty dictionary if attribute isn't present yet.
-        ### parameter
-            sAttr   ... dictionary name, object attribute
-            bChk    ... check only
-        ### return
-            if bChk==False
-                dictionary
-            if bChk==True
-                boolean check
-                True    ... attribute present
-                False   ... or not
-            None    ... exception
+        
+        Args:
+            sAttr (str): dictionary name, object attribute
+            bChk (bool , optional): check only
+        
+        Returns:
+            return obj
+                - dictionary, if bChk==False
+                - bool, boolean check if bChk==True
+                    - True : attribute present
+                    - False : or not
+                - None : exception
         """
         try:
             bDbg=self.GetVerboseDbg(0)
@@ -317,12 +336,14 @@ class ldmWidCore(ldmUtilLog,ldmWidCoreEvt):
         """get widget (control) id, used in GUI framework
         reuse id for similar controls, which are cached
         in global dictionary, build by use of ldmWidCoreCtrlId.
-        ### parameter
-            sKey    ... primary key
-                        None uses class name instead
-            sSub    ... secondary key
-        ### return
-            widget id
+        
+        Args:
+            sKey (str): primary key
+                - None uses class name instead
+            sSub (str): secondary key
+        
+        Returns
+            int: widget id
         """
         if sKey is None:
             return ldmWidCoreCtrlId(self.__class__.__name__,sSub)
@@ -331,15 +352,15 @@ class ldmWidCore(ldmUtilLog,ldmWidCoreEvt):
     def GetKw(self,kwargs,lKey,dDft=None,kag=None):
         """get keyword arguments lightweight copy with
         defaults mixed in.
-        ### parameter
-            kwargs  ... original keyword arguments at constructor
-            lKey    ... list of required keyword arguments returned
-            dDft    ... default values
-            kag     ... dictionary preset, None create a new dictionary
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        
+        Args:
+            kwargs (dict): original keyword arguments at constructor
+            lKey (list): list of required keyword arguments returned
+            dDft (dict): default values
+            kag (obj): dictionary preset, None create a new dictionary
+        
+        Returns:
+            dict: kag, key word arguments dictionary
         """
         if kag is None:
             kag={}
@@ -368,23 +389,26 @@ class ldmWidCore(ldmUtilLog,ldmWidCoreEvt):
         method GetCtrlId is used to get widget id determined by
         parent name and sSub. similar ids shall be used through
         entire application.
-        ### parameter
-            kwargs  ... original keyword arguments at constructor
-            lKey    ... list of required keyword arguments returned
-            dDft    ... default values
-            kag     ... dictionary preset, None create a new dictionary
-            sSub .. 
-            bValidate . enforce elementary arguments to be present,
-                        pos ... widget position (wx.DefaultPosition)
-                        size .. widget size (wx.DefaultSize)
-            par     ... parent object/widget, determine parent name
-                        GetWid is used to retrieve widget of object
-            lArg    ... list of arguments removed from keyword 
-                        and 
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+
+        additional arguments might be:
+            - pos (obj , optional): widget position (wx.DefaultPosition)
+            - size (obj , optional): widget size (wx.DefaultSize)
+        
+        Args:
+            kwargs (dict): original keyword arguments at constructor
+            lKey (list): list of required keyword arguments returned
+            dDft (dict): default values
+            kag (dict , optional): dictionary preset, None create a new dictionary
+            sSub (str , optional): sub name
+            bValidate (bool , optional): enforce elementary arguments to be present,
+            par (wid , optional): parent object/widget, determine parent name
+                - GetWid is used to retrieve widget of object
+            lArg (list): list of arguments removed from keyword 
+        
+        Returns:
+            tuple
+                list: arg, argument list
+                dict: kag, key word arguments dictionary
         """
         lArgs=[]
         kag=self.GetKw(kwargs,lKey,dDft,kag=kag)
@@ -447,10 +471,11 @@ class ldmWidCore(ldmUtilLog,ldmWidCoreEvt):
         """callback func/method in main thread
         widget manipulation inside a thread may cause
         stability issues.
-        ### parameter
-            func    ... callable
-            args    ... arguments to pass
-            kwargs  ... keyword arguments to pass
+        
+        Args:
+            func (callable): callable
+            args (list): arguments to pass
+            kwargs (dict): keyword arguments to pass
         """
         try:
             wx.CallAfter(func,*args,**kwargs)
@@ -460,11 +485,12 @@ class ldmWidCore(ldmUtilLog,ldmWidCoreEvt):
         """delayed callback func/method in main thread
         widget manipulation inside a thread may cause
         stability issues.
-        ### parameter
-            zSleep  ... delay time in seconds
-            func    ... callable
-            args    ... arguments to pass
-            kwargs  ... keyword arguments to pass
+        
+        Args:
+            zSleep (float): delay time in seconds
+            func (callable): callable
+            args (list): arguments to pass
+            kwargs (dict): keyword arguments to pass
         """
         try:
             wx.CallAfter(wx.FutureCall,int(zSleep*1000),func,*args,**kwargs)
@@ -472,20 +498,22 @@ class ldmWidCore(ldmUtilLog,ldmWidCoreEvt):
             self.logTB()
     def setCfgWid(self,sGrp,sKey,sVal,iMode=1):
         """get configuration value
-        ### parameter
-            sGrp    ... configuration group
-            sKey    ... configuration key
-            sVal    ... value
-            iMode   ... configuration dictionary to change
-                1   ... default dictionary
-                2   ... active dictionary
-                3   ... both
-                <=0 ... default dictionary
-        ### return
+        
+        Args:
+            sGrp (str): configuration group
+            sKey (str): configuration key
+            sVal (str): value
+            iMode (int): configuration dictionary to change
+                - 1   : default dictionary
+                - 2   : active dictionary
+                - 3   : both
+                - <=0 : default dictionary
+        
+        Returns:
             return code
-                >0  ... okay processing done
-                =0  ... okay nop
-                <0  ... error
+                - >0 : okay processing done
+                - =0 : okay nop
+                - <0 : error
         """
         try:
             # +++++ beg:initialize
@@ -524,19 +552,23 @@ class ldmWidCore(ldmUtilLog,ldmWidCoreEvt):
             return -1
     def getCfgWidTup(self,sGrp,sKey,sType=None,oDft=None):
         """get configuration value and return code
-        ### parameter
-            sGrp    ... configuration group
-            sKey    ... configuration key
-            sType   ... type enforcement
-            oDft    ... default value
-        ### return
-            return code
-                1   ... value taken from defaults dictionary
-                2   ... value taken from active dictionary
-                >0  ... okay processing done
-                =0  ... okay nop
-                <0  ... error
-            value
+        
+        Args:
+            sGrp (str): configuration group
+            sKey (str): configuration key
+            sType (str , optional): type enforcement
+            oDft (obj , optional): default value
+        
+        Returns:
+            tuple
+                return code
+                    - 1  : value taken from defaults dictionary
+                    - 2  : value taken from active dictionary
+                    - >0 : okay processing done
+                    - =0 : okay nop
+                    - <0 : error
+                
+                value
         """
         try:
             # +++++ beg:initialize
@@ -576,13 +608,15 @@ class ldmWidCore(ldmUtilLog,ldmWidCoreEvt):
             return -1,None
     def getCfgWid(self,sGrp,sKey,sType=None,oDft=None):
         """get configuration value
-        ### parameter
-            sGrp    ... configuration group
-            sKey    ... configuration key
-            sType   ... type enforcement
-            oDft    ... default value
-        ### return
-            value   ... value
+        
+        Args:
+            sGrp (str): configuration group
+            sKey (str): configuration key
+            sType (str , optional): type enforcement
+            oDft (obj , optional): default value
+        
+        Returns:
+            obj: value
         """
         try:
             # +++++ beg:initialize
@@ -597,12 +631,16 @@ class ldmWidCore(ldmUtilLog,ldmWidCoreEvt):
             return oDft
     def loadCfgWid(self,sCfgFN='cfg.json'):
         """read configuration file, given in json format
-        ### parameter
-            sCfgFN  ... configuration file name
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        configuration is place in dCfgWid, or it's None
+        
+        Args:
+            sCfgFN (str , optional): configuration file name
+        
+        Returns:
+            return code
+                - >0 : okay processing done
+                - =0 : okay nop
+                - <0 : error
         """
         try:
             # +++++ beg:initialize
@@ -630,6 +668,13 @@ class ldmWidCore(ldmUtilLog,ldmWidCoreEvt):
             self.logTB()
             return -1
     def IsMainThread(self,bMain=True,bSilent=False):
+        """is main thread, important, widget might be sensitive from where they are manipulated
+
+        Returns:
+            return code
+                - True: main thread, manipulation is safe
+                - False: thread, unsafe to manipulate
+        """
         return True
         if wx.Thread_IsMain()!=bMain:
             if bSilent==False:
@@ -639,3 +684,25 @@ class ldmWidCore(ldmUtilLog,ldmWidCoreEvt):
                     self.logCri('called by main thread'%())
             return False
         return True
+    def __getThread__(self,sName):
+        """get thread by name, create if not present already
+
+        Args:
+            sName (str): thread name
+        
+        Returns:
+            ldmGuiThd: thread object
+        """
+        try:
+            bDbg=self.GetVerboseDbg(10)
+            if bDbg:
+                self.logDbg(''%())
+            sThdName='_oThd'+sName
+            if hasattr(self,sThdName)==False:
+                oThd=ldmGuiThd()
+                self.__dict__[sThdName]=oThd
+                return oThd
+            else:
+                return self.__dict__[sThdName]
+        except:
+            self.logTB()
