@@ -16,6 +16,8 @@ gdSysEvtName={}
 gTypeString=type('')
 
 def ldmWidCoreKeyCode(evt):
+    """get key code, version independent
+    """
     if wx.VERSION >= (2,8):
         return evt.GetKeyCode()
     else:
@@ -37,6 +39,13 @@ class ldmWidCoreCmd(wx.PyEvent):
             EVT_WID_CORE_CMD(<widget_name>, xxx)
     """
     def __init__(self,obj,cmd,data=None):
+        """constructor
+
+        Args:
+            obj (obj): object
+            cmd (str): event name
+            data (obj): data to pass along
+        """
         wx.PyEvent.__init__(self)
         self.SetEventObject(obj)
         self.SetId(obj.GetId())
@@ -44,8 +53,18 @@ class ldmWidCoreCmd(wx.PyEvent):
         self.cmd=cmd
         self.data=data
     def GetCmd(self):
+        """get command name
+
+        Returns:
+            str: command name
+        """
         return self.cmd
     def GetData(self):
+        """get data
+
+        Returns:
+            obr: data
+        """
         return self.data
     GetDat=GetData
 
@@ -66,6 +85,13 @@ class ldmWidCoreOk(wx.PyEvent):
             EVT_WID_CORE_OK(<widget_name>, xxx)
     """
     def __init__(self,obj,res,data=None):
+        """constructor
+
+        Args:
+            obj (obj): object
+            cmd (str): event name
+            data (obj): data to pass along
+        """
         wx.PyEvent.__init__(self)
         self.SetEventObject(obj)
         self.SetId(obj.GetId())
@@ -76,6 +102,11 @@ class ldmWidCoreOk(wx.PyEvent):
         return self.res
     GetRlt=GetResult
     def GetData(self):
+        """get data
+
+        Returns:
+            obr: data
+        """
         return self.data
     GetDat=GetData
 
@@ -95,6 +126,13 @@ class ldmWidCoreCancel(wx.PyEvent):
             EVT_WID_CORE_CANCEL(<widget_name>, xxx)
     """
     def __init__(self,obj,res,data=None):
+        """constructor
+
+        Args:
+            obj (obj): object
+            res (str): result
+            data (obj): data to pass along
+        """
         wx.PyEvent.__init__(self)
         self.SetEventObject(obj)
         self.SetId(obj.GetId())
@@ -105,6 +143,11 @@ class ldmWidCoreCancel(wx.PyEvent):
         return self.res
     GetRlt=GetResult
     def GetData(self):
+        """get data
+
+        Returns:
+            obr: data
+        """
         return self.data
     GetDat=GetData
 
@@ -124,6 +167,13 @@ class ldmWidCoreFB(wx.PyEvent):
             EVT_WID_CORE_FB(<widget_name>, xxx)
     """
     def __init__(self,obj,fb,data=None):
+        """constructor
+
+        Args:
+            obj (obj): object
+            fb (obj): feedback
+            data (obj): data to pass along
+        """
         wx.PyEvent.__init__(self)
         self.SetEventObject(obj)
         self.SetId(obj.GetId())
@@ -133,6 +183,11 @@ class ldmWidCoreFB(wx.PyEvent):
     def GetFB(self):
         return self.fb
     def GetData(self):
+        """get data
+
+        Returns:
+            obr: data
+        """
         return self.data
     GetDat=GetData
 
@@ -152,6 +207,14 @@ class ldmWidCoreMOD(wx.PyEvent):
             EVT_WID_CORE_MOD(<widget_name>, xxx)
     """
     def __init__(self,obj,res,data=None,gui=None):
+        """constructor
+
+        Args:
+            obj (obj): object
+            res (str): result
+            data (obj , optional): data to pass along
+            gui (obj , optional): widget
+        """
         wx.PyEvent.__init__(self)
         self.SetEventObject(obj)
         self.SetId(obj.GetId())
@@ -163,6 +226,11 @@ class ldmWidCoreMOD(wx.PyEvent):
         return self.res
     GetRlt=GetResult
     def GetData(self):
+        """get data
+
+        Returns:
+            obr: data
+        """
         return self.data
     GetDat=GetData
     def GetGUI(self):
@@ -184,6 +252,14 @@ class ldmWidCoreNFY(wx.PyEvent):
             EVT_WID_CORE_NFY(<widget_name>, xxx)
     """
     def __init__(self,obj,res,data=None,gui=None):
+        """constructor
+
+        Args:
+            obj (obj): object
+            res (str): result
+            data (obj , optional): data to pass along
+            gui (obj , optional): widget
+        """
         wx.PyEvent.__init__(self)
         self.SetEventObject(obj)
         self.SetId(obj.GetId())
@@ -195,6 +271,11 @@ class ldmWidCoreNFY(wx.PyEvent):
         return self.res
     GetRlt=GetResult
     def GetData(self):
+        """get data
+
+        Returns:
+            obr: data
+        """
         return self.data
     GetDat=GetData
     def GetGUI(self):
@@ -216,6 +297,15 @@ class ldmWidCoreADT(wx.PyEvent):
             EVT_WID_CORE_ADT(<widget_name>, xxx)
     """
     def __init__(self,obj,res,old=None,new=None,gui=None):
+        """constructor
+
+        Args:
+            obj (obj): object
+            res (str): result
+            old (obj , optional): old data to pass along
+            new (obj , optional): new data to pass along
+            gui (obj , optional): widget
+        """
         wx.PyEvent.__init__(self)
         self.SetEventObject(obj)
         self.SetId(obj.GetId())
@@ -238,6 +328,16 @@ class ldmWidCoreEvt:
     _MAP_EVENT={}
     _MAP_EVENT_UNBIND={}
     def BindEvent(self,name,func,par=None):
+        """bind event handler to widget
+        
+        Args:
+            name (str): event specifier
+                - withing _MAP_EVENT
+                - resolvable by __get_Widget_event
+                - EVENT object itself
+            func (callable): event handler
+            par (wid , optional): parent widget, see wxPython manual Bind
+        """
         try:
             bDbg=self.GetVerboseDbg(100)
             if bDbg:
@@ -280,6 +380,16 @@ class ldmWidCoreEvt:
             self.logTB()
         return -1
     def UnBindEvent(self,name,func,par=None):
+        """unbind event handler, inverse method to BindEvent
+
+        Args:
+            name (str): event specifier
+                - withing _MAP_EVENT
+                - resolvable by __get_Widget_event
+                - EVENT object itself
+            func (callable): event handler
+            par (wid , optional): parent widget, see wxPython manual Bind
+        """
         try:
             # ++++++++++
             # 20141125 wro: event mapping added
@@ -303,6 +413,13 @@ class ldmWidCoreEvt:
             self.logTB()
         return -1
     def __get_widget_event__(self,sK):
+        """resolve event object
+        
+        Args:
+            sK (str): string identifying event object
+                - 'txt'   ... wx.EVT_TEXT
+
+        """
         try:
             bDbg=self.GetVerboseDbg(100)
             if bDbg:
@@ -463,6 +580,11 @@ class ldmWidCoreEvt:
             self.logTB()
         return None
     def GetSysEvtNameByEvt(self,evt):
+        """get event name by event object
+
+        Args:
+            evt (obj): wx event type
+        """
         try:
             global gdSysEvtName
             bDbg=self.GetVerboseDbg(100)
@@ -484,6 +606,16 @@ class ldmWidCoreEvt:
         except:
             self.logTB()
     def BindEventDict(self,wid,dEvt):
+        """bind event handler by dictionary
+        
+        Args:
+            wid (wid): widget
+            dEvt (dict): event dictionary
+                {
+                    'txt':  function_text_changed,
+                    'ent':  function_text_emtered
+                }
+        """
         try:
             bDbg=self.GetVerboseDbg(100)
             if bDbg:
@@ -496,6 +628,13 @@ class ldmWidCoreEvt:
         except:
             self.logTB()
     def BindEventWid(self,wid,sEvt,fct):
+        """bind event handler
+        
+        Args:
+            wid (wid): widget
+            sEvt (str): event descriptor resolved by __get_widget_event__
+            fct (callable): event handler
+        """
         try:
             bDbg=self.GetVerboseDbg(100)
             if bDbg:
