@@ -22,6 +22,8 @@ from lindworm.ldmWidTree import ldmWidTree
 
 #class ldmAuiMpw(aui.AuiMDIParentFrame):
 class ldmWidFrmAui(ldmWidCore):
+    """GUI frame using AUI framework
+    """
     ID_TBR_File=100
     ID_FILE_OPEN=101
     ID_FILE_SAVE=102
@@ -32,8 +34,86 @@ class ldmWidFrmAui(ldmWidCore):
     ID_CMD=300
     ID_DST=700
     def __initCls__(self,**kwargs):
+        """class initializer, set self.clsWid to wxPython class
+        """
         self.clsWid=wx.Frame
     def __initCfg__(self,**kwargs):
+        """initialize configuration
+        configuration can be applied via json file
+        add configuration values to dCfgWid
+            {
+            'toolbar':{
+                'bmp.iSz': '32',
+                'command':'1',
+                'destination':'1'
+                },
+            'tbrFile':{
+                'enable':'1',
+                'open.tip':'Open Json File',
+                'save.tip':'Save Json File'
+                },
+            'tbrEdit':{
+                'enable':'1',
+                'cut.tip':'cut',
+                'copy.tip':'copy',
+                'paste.tip':'paste'
+                },
+            'tbrCmd':{
+                '00.enable':'1',
+                '01.enable':'1',
+                '02.enable':'1',
+                '03.enable':'1',
+                '04.enable':'0',
+                '05.enable':'0',
+                '06.enable':'0',
+                '07.enable':'0',
+                '08.enable':'0',
+                '09.enable':'0',
+                '00.tip':'command 00',
+                '01.tip':'command 01',
+                '02.tip':'command 02',
+                '03.tip':'command 03',
+                '04.tip':'command 04',
+                '05.tip':'command 05',
+                '06.tip':'command 06',
+                '07.tip':'command 07',
+                '08.tip':'command 08',
+                '09.tip':'command 09'
+                },
+            'menubar':{
+                'command':'1'
+                },
+            'mnrCmd':{
+                '00.enable':'1',
+                '01.enable':'1',
+                '02.enable':'1',
+                '03.enable':'1',
+                '04.enable':'0',
+                '05.enable':'0',
+                '06.enable':'0',
+                '07.enable':'0',
+                '08.enable':'0',
+                '09.enable':'0',
+                '00.menu':'command 00',
+                '01.menu':'command 01',
+                '02.menu':'command 02',
+                '03.menu':'command 03',
+                '04.menu':'command 04',
+                '05.menu':'command 05',
+                '06.menu':'command 06',
+                '07.menu':'command 07',
+                '08.menu':'command 08',
+                '09.menu':'command 09'
+                },
+            'frmMain':{
+                'sToolBarCommand','0',
+                'sToolBarDestination','0'
+                }
+            }
+        
+        Args:
+            kwargs (dict): keyword arguments passed to all init methods
+        """
         try:
             # +++++ beg:initialize
             sOrg='ldmWidFrmAui::__initCfg__'
@@ -41,9 +121,6 @@ class ldmWidFrmAui(ldmWidCore):
             ldmWidCore.__initCfg__(self,**kwargs)
             # ----- end:initialize
             # +++++ beg:
-            self.tTbrBmpSz=wx.Size(32, 32)
-            # ----- end:
-            # +++++ beg:
             self.setCfgWid('toolbar','bmp.iSz','32')
             # ----- end:
             # +++++ beg:toolbar file
@@ -123,8 +200,14 @@ class ldmWidFrmAui(ldmWidCore):
         """initialize object properties, widgets aren't present yet.
         data is supposed to be related to widgets or support their
         function.
-        ### parameter
-            kwargs  ... keyword arguments passed to all init methods
+            {
+            'toolbar':{
+                'bmp.iSz': '32',
+                },
+            }
+        
+        Args:
+            kwargs (dict): keyword arguments passed to all init methods
         """
         try:
             # +++++ beg:initialize
@@ -145,8 +228,19 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def __initWid__(self,**kwargs):
         """initialize widget
-        ### parameter
-            kwargs  ... keyword arguments
+            {
+            'help':{
+                'tab': 'help',
+                'text':'..',
+                },
+            'frmMain':{
+                'sToolBarCommand','0',
+                'sToolBarDestination','0'
+                }
+            }
+        
+        Args:
+            kwargs (dict): keyword arguments
         """
         try:
             # +++++ beg:
@@ -225,8 +319,15 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def __initToolBar__(self,**kwargs):
         """initialize toolbars
-        ### parameter
-            kwargs  ... keyword arguments
+            {
+            'toolbar':{
+                'command':'1',
+                'destination':'1'
+                },
+            }
+        
+        Args:
+            kwargs (dict): keyword arguments
         """
         try:
             # +++++ beg:initialize
@@ -250,8 +351,16 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def __initTbrFile__(self,**kwargs):
         """initialize toolbar file
-        ### parameter
-            kwargs  ... keyword arguments
+            {
+            'tbrFile':{
+                'enable':'1',
+                'open.tip':'Open Json File',
+                'save.tip':'Save Json File'
+                },
+            }
+        
+        Args:
+            kwargs (dict): keyword arguments
         """
         try:
             # +++++ beg:initialize
@@ -297,8 +406,17 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def __initTbrEdit__(self,**kwargs):
         """initialize toolbar edit
-        ### parameter
-            kwargs  ... keyword arguments
+            {
+            'tbrEdit':{
+                'enable':'1',
+                'cut.tip':'cut',
+                'copy.tip':'copy',
+                'paste.tip':'paste'
+                },
+            }
+        
+        Args:
+            kwargs (dict): keyword arguments
         """
         try:
             # +++++ beg:initialize
@@ -352,8 +470,33 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def __initTbrCmd__(self,**kwargs):
         """initialize toolbar command
-        ### parameter
-            kwargs  ... keyword arguments
+            {
+            'tbrCmd':{
+                '00.enable':'1',
+                '01.enable':'1',
+                '02.enable':'1',
+                '03.enable':'1',
+                '04.enable':'0',
+                '05.enable':'0',
+                '06.enable':'0',
+                '07.enable':'0',
+                '08.enable':'0',
+                '09.enable':'0',
+                '00.tip':'command 00',
+                '01.tip':'command 01',
+                '02.tip':'command 02',
+                '03.tip':'command 03',
+                '04.tip':'command 04',
+                '05.tip':'command 05',
+                '06.tip':'command 06',
+                '07.tip':'command 07',
+                '08.tip':'command 08',
+                '09.tip':'command 09'
+                },
+            }
+        
+        Args:
+            kwargs (dict): keyword arguments
         """
         try:
             # +++++ beg:initialize
@@ -492,8 +635,33 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def __initTbrDst__(self,**kwargs):
         """initialize toolbar destination
-        ### parameter
-            kwargs  ... keyword arguments
+            {
+            'tbrDst':{
+                '00.enable':'1',
+                '01.enable':'1',
+                '02.enable':'1',
+                '03.enable':'1',
+                '04.enable':'0',
+                '05.enable':'0',
+                '06.enable':'0',
+                '07.enable':'0',
+                '08.enable':'0',
+                '09.enable':'0',
+                '00.tip':'destination 00',
+                '01.tip':'destination 01',
+                '02.tip':'destination 02',
+                '03.tip':'destination 03',
+                '04.tip':'destination 04',
+                '05.tip':'destination 05',
+                '06.tip':'destination 06',
+                '07.tip':'destination 07',
+                '08.tip':'destination 08',
+                '09.tip':'destination 09'
+                },
+            }
+        
+        Args:
+            kwargs (dict): keyword arguments
         """
         try:
             # +++++ beg:initialize
@@ -669,8 +837,9 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def __initPanCt__(self,**kwargs):
         """initialize pane center
-        ### parameter
-            kwargs  ... keyword arguments
+        
+        Args:
+            kwargs (dict): keyword arguments
         """
         try:
             # +++++ beg:initialize
@@ -703,8 +872,9 @@ class ldmWidFrmAui(ldmWidCore):
         return None
     def __initPanLf__(self,**kwargs):
         """initialize pane left
-        ### parameter
-            kwargs  ... keyword arguments
+        
+        Args:
+            kwargs (dict): keyword arguments
         """
         try:
             # +++++ beg:initialize
@@ -725,8 +895,9 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def __initPanBt__(self,**kwargs):
         """initialize pane button
-        ### parameter
-            kwargs  ... keyword arguments
+        
+        Args:
+            kwargs (dict): keyword arguments
         """
         try:
             # +++++ beg:initialize
@@ -752,8 +923,56 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def __initMenuBar__(self,**kwargs):
         """initialize menu bar
-        ### parameter
-            kwargs  ... keyword arguments
+            {
+            'mnrCmd':{
+                '00.enable':'1',
+                '01.enable':'1',
+                '02.enable':'1',
+                '03.enable':'1',
+                '04.enable':'0',
+                '05.enable':'0',
+                '06.enable':'0',
+                '07.enable':'0',
+                '08.enable':'0',
+                '09.enable':'0',
+                '00.menu':'command 0',
+                '01.menu':'command 1',
+                '02.menu':'command 2',
+                '03.menu':'command 3',
+                '04.menu':'command 4',
+                '05.menu':'command 5',
+                '06.menu':'command 6',
+                '07.menu':'command 7',
+                '08.menu':'command 8',
+                '09.menu':'command 9'
+                },
+            'mnrDst':{
+                'menu':'destination',
+                '00.enable':'1',
+                '01.enable':'1',
+                '02.enable':'1',
+                '03.enable':'1',
+                '04.enable':'0',
+                '05.enable':'0',
+                '06.enable':'0',
+                '07.enable':'0',
+                '08.enable':'0',
+                '09.enable':'0',
+                '00.menu':'dest 0',
+                '01.menu':'dest 1',
+                '02.menu':'dest 2',
+                '03.menu':'dest 3',
+                '04.menu':'dest 4',
+                '05.menu':'dest 5',
+                '06.menu':'dest 6',
+                '07.menu':'dest 7',
+                '08.menu':'dest 8',
+                '09.menu':'dest 9'
+                },
+            }
+        
+        Args:
+            kwargs (dict): keyword arguments
         """
         try:
             # +++++ beg:initialize
@@ -925,8 +1144,9 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def __initStatusBar__(self,**kwargs):
         """initialize status bar
-        ### parameter
-            kwargs  ... keyword arguments
+        
+        Args:
+            kwargs (dict): keyword arguments
         """
         try:
             # +++++ beg:initialize
@@ -943,8 +1163,9 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def __initEvt__(self,**kwargs):
         """initialize event
-        ### parameter
-            kwargs  ... keyword arguments
+        
+        Args:
+            kwargs (dict): keyword arguments
         """
         try:
             # +++++ beg:initialize
@@ -975,8 +1196,9 @@ class ldmWidFrmAui(ldmWidCore):
         return self.mgrMain.GetArtProvider()
     def OnFileOpen(self,evt):
         """event handler
-        ### parameter
-            evt     ... event object
+        
+        Args:
+            evt (obj): event object
         """
         try:
             self.logDbg('OnFileOpen')
@@ -984,8 +1206,9 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def OnFileSave(self,evt):
         """event handler
-        ### parameter
-            evt     ... event object
+
+        Args:
+            evt (obj): event object
         """
         try:
             self.logDbg('OnFileSave')
@@ -993,8 +1216,9 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def OnEditCut(self,evt):
         """event handler
-        ### parameter
-            evt     ... event object
+        
+        Args:
+            evt (obj): event object
         """
         try:
             self.logDbg('OnEditCut')
@@ -1002,8 +1226,9 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def OnEditCopy(self,evt):
         """event handler
-        ### parameter
-            evt     ... event object
+        
+        Args:
+            evt (obj): event object
         """
         try:
             self.logDbg('OnEditCopy')
@@ -1011,8 +1236,9 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def OnEditPaste(self,evt):
         """event handler of edit past
-        ### parameter
-            evt     ... event object
+        
+        Args:
+            evt (obj): event object
         """
         try:
             self.logDbg('OnEditPaste')
@@ -1020,16 +1246,19 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def prcCmd(self,sCmd):
         """process command, called by event default handler
-        ### parameter
-            sCmd    ... command name
-                cmd00   ... command button 00, tbrCmd.00
-                cmd01   ... command button 00, tbrCmd.01
-                ..
-                cmd09   ... command button 00, tbrCmd.09
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
+        
+        Args:
+            sCmd (str): command name
+                - cmd00 : command button 00, tbrCmd.00
+                - cmd01 : command button 00, tbrCmd.01
+                - ..
+                - cmd09 : command button 00, tbrCmd.09
+        
+        Returns:
+            return code
+                - >0 : okay processing done
+                - =0 : okay nop
+                - <0 : error
         """
         try:
             # +++++ beg:initialize
@@ -1048,8 +1277,9 @@ class ldmWidFrmAui(ldmWidCore):
             return -1
     def OnCmd00(self,evt):
         """event handler for command button 00
-        ### parameter
-            evt     ... event object
+        
+        Args:
+            evt (obj): event object
         """
         try:
             # +++++ beg:initialize
@@ -1066,8 +1296,9 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def OnCmd01(self,evt):
         """event handler for command button 01
-        ### parameter
-            evt     ... event object
+        
+        Args:
+            evt (obj): event object
         """
         try:
             # +++++ beg:initialize
@@ -1084,8 +1315,9 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def OnCmd02(self,evt):
         """event handler for command button 02
-        ### parameter
-            evt     ... event object
+        
+        Args:
+            evt (obj): event object
         """
         try:
             # +++++ beg:initialize
@@ -1102,8 +1334,9 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def OnCmd03(self,evt):
         """event handler for command button 03
-        ### parameter
-            evt     ... event object
+        
+        Args:
+            evt (obj): event object
         """
         try:
             # +++++ beg:initialize
@@ -1120,8 +1353,9 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def OnCmd04(self,evt):
         """event handler for command button 04
-        ### parameter
-            evt     ... event object
+        
+        Args:
+            evt (obj): event object
         """
         try:
             # +++++ beg:initialize
@@ -1138,8 +1372,9 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def OnCmd05(self,evt):
         """event handler for command button 05
-        ### parameter
-            evt     ... event object
+        
+        Args:
+            evt (obj): event object
         """
         try:
             # +++++ beg:initialize
@@ -1156,8 +1391,9 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def OnCmd06(self,evt):
         """event handler for command button 06
-        ### parameter
-            evt     ... event object
+        
+        Args:
+            evt (obj): event object
         """
         try:
             # +++++ beg:initialize
@@ -1174,8 +1410,9 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def OnCmd07(self,evt):
         """event handler for command button 07
-        ### parameter
-            evt     ... event object
+        
+        Args:
+            evt (obj): event object
         """
         try:
             # +++++ beg:initialize
@@ -1192,8 +1429,9 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def OnCmd08(self,evt):
         """event handler for command button 08
-        ### parameter
-            evt     ... event object
+        
+        Args:
+            evt (obj): event object
         """
         try:
             # +++++ beg:initialize
@@ -1210,8 +1448,9 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def OnCmd09(self,evt):
         """event handler for command button 09
-        ### parameter
-            evt     ... event object
+        
+        Args:
+            evt (obj): event object
         """
         try:
             # +++++ beg:initialize
@@ -1228,8 +1467,9 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def OnDst00(self,evt):
         """event handler for destination button 00
-        ### parameter
-            evt     ... event object
+        
+        Args:
+            evt (obj): event object
         """
         try:
             # +++++ beg:initialize
@@ -1246,8 +1486,9 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def OnDst01(self,evt):
         """event handler for destination button 01
-        ### parameter
-            evt     ... event object
+        
+        Args:
+            evt (obj): event object
         """
         try:
             # +++++ beg:initialize
@@ -1264,8 +1505,9 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def OnDst02(self,evt):
         """event handler for destination button 02
-        ### parameter
-            evt     ... event object
+        
+        Args:
+            evt (obj): event object
         """
         try:
             # +++++ beg:initialize
@@ -1282,8 +1524,9 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def OnDst03(self,evt):
         """event handler for destination button 03
-        ### parameter
-            evt     ... event object
+        
+        Args:
+            evt (obj): event object
         """
         try:
             # +++++ beg:initialize
@@ -1300,8 +1543,9 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def OnDst04(self,evt):
         """event handler for destination button 04
-        ### parameter
-            evt     ... event object
+        
+        Args:
+            evt (obj): event object
         """
         try:
             # +++++ beg:initialize
@@ -1318,8 +1562,9 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def OnDst05(self,evt):
         """event handler for destination button 05
-        ### parameter
-            evt     ... event object
+        
+        Args:
+            evt (obj): event object
         """
         try:
             # +++++ beg:initialize
@@ -1336,8 +1581,9 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def OnDst06(self,evt):
         """event handler for destination button 06
-        ### parameter
-            evt     ... event object
+        
+        Args:
+            evt (obj): event object
         """
         try:
             # +++++ beg:initialize
@@ -1354,8 +1600,9 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def OnDst07(self,evt):
         """event handler for destination button 07
-        ### parameter
-            evt     ... event object
+        
+        Args:
+            evt (obj): event object
         """
         try:
             # +++++ beg:initialize
@@ -1372,8 +1619,9 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def OnDst08(self,evt):
         """event handler for destination button 08
-        ### parameter
-            evt     ... event object
+        
+        Args:
+            evt (obj): event object
         """
         try:
             # +++++ beg:initialize
@@ -1390,8 +1638,9 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def OnDst09(self,evt):
         """event handler for destination button 09
-        ### parameter
-            evt     ... event object
+        
+        Args:
+            evt (obj): event object
         """
         try:
             # +++++ beg:initialize
@@ -1406,30 +1655,34 @@ class ldmWidFrmAui(ldmWidCore):
             # ----- end:finalize
         except:
             self.logTB()
-    def OnFrmEraseBackground(self, event):
+    def OnFrmEraseBackground(self, evt):
         """event handler
-        ### parameter
-            evt     ... event object
+        
+        Args:
+            evt (obj): event object
         """
-        event.Skip()
-    def OnFrmSize(self, event):
+        evt.Skip()
+    def OnFrmSize(self, evt):
         """event handler
-        ### parameter
-            evt     ... event object
+        
+        Args:
+            evt (obj): event object
         """
-        event.Skip()
-    def OnFrmClose(self, event):
+        evt.Skip()
+    def OnFrmClose(self, evt):
         """event handler
-        ### parameter
-            evt     ... event object
+        
+        Args:
+            evt (obj): event object
         """
         #self.timer.Stop()
         self.mgrMain.UnInit()
-        event.Skip()
-    def OnExit(self, event):
+        evt.Skip()
+    def OnExit(self, evt):
         """event handler
-        ### parameter
-            evt     ... event object
+        
+        Args:
+            evt (obj): event object
         """
         try:
             self.logDbg('OnExit')
@@ -1438,8 +1691,6 @@ class ldmWidFrmAui(ldmWidCore):
             self.logTB()
     def DoUpdate(self):
         """event handler
-        ### parameter
-            evt     ... event object
         """
         self.mgrMain.Update()
         self.Refresh()
