@@ -15,15 +15,9 @@ import wx
 
 import six
 
+import lindworm.ldmTypes as ldmTypes
 from lindworm.ldmWidCore import ldmWidCore
 
-
-typesIntType=type(1)
-typesStringType=type('')
-typesDictType=type({})
-typesListType=type([])
-typesTupleType=type(())
-
 class ldmWidList(ldmWidCore):
     """list control widget shell to harmonize widget interface
     and ease usage.
@@ -36,18 +30,20 @@ class ldmWidList(ldmWidCore):
     """
     def __initCls__(self,**kwargs):
         """initialize class
-        ### parameter
-            kwargs  ... keyword arguments passed to all init methods
+        
+        Args:
+            kwargs (dict): keyword arguments passed to all init methods
         """
         self.clsWid=wx.ListCtrl
     def __initCfg__(self,**kwargs):
         """initialize configuration
-        ### parameter
-            kwargs  ... keyword arguments passed to all init methods
+        
+        Args:
+            kwargs (dict): keyword arguments passed to all init methods
         """
         try:
             # +++++ beg:initialize
-            sOrg='ldmWidCore::__initCfg__'
+            sOrg='ldmWidList::__initCfg__'
             self.logDbg('beg:%s'%(sOrg))
             # ----- end:initialize
             ldmWidCore.__initCfg__(self,**kwargs)
@@ -63,8 +59,9 @@ class ldmWidList(ldmWidCore):
         """initialize object properties, widgets aren't present yet.
         data is supposed to be related to widgets or support their
         function.
-        ### parameter
-            kwargs  ... keyword arguments passed to all init methods
+        
+        Args:
+            kwargs (dict): keyword arguments passed to all init methods
         """
         try:
             # +++++ beg:initialize
@@ -89,12 +86,25 @@ class ldmWidList(ldmWidCore):
             self.logTB()
     def __initWid__(self,**kwargs):
         """initialize widgets
-        ### parameter
-            kwargs  ... keyword arguments passed to all init methods
+        
+        Args:
+            kwargs (dict): keyword arguments passed to all init methods
+                lCol ... column formating
+                    [
+                        (100,'l),       # 100 pixel, left alignment
+                        (200,'lf),      # 200 pixel, left alignment
+                        (100,'c),       # 100 pixel, center alignment
+                        (200,'ct),      # 200 pixel, center alignment
+                        (100,'r),       # 100 pixel, right alignment
+                        (200,'rg),      # 200 pixel, right alignment
+                        (-1,'l),        # growable factor 1, left alignment
+                        (-2,'lf),       # growable factor 2, left alignment
+                    ],
+                map ... mapping
         """
         try:
             # +++++ beg:initialize
-            sOrg='ldmWidCore::__initWid__'
+            sOrg='ldmWidList::__initWid__'
             self.logDbg('beg:%s'%(sOrg))
             # ----- end:initialize
             # +++++ beg:
@@ -144,15 +154,22 @@ class ldmWidList(ldmWidCore):
             self.logTB()
     def SetItem(self,idx,i,v):
         """set list column item
-        ### parameter
-            idx     ... 
-            i       ... column
-                    <0  ... data
-                    >=0 ... column
-            v       ... value
-                    integer value, interpreted as image index
-                    tuple, t[0] string value, t[1] image index
-                    string or unicode value, image cleared
+        
+        Args:
+            idx (int): index 
+            i (int): column
+                - <0  ... data
+                - >=0 ... column
+            v (obj): value
+                - integer value, interpreted as image index
+                - tuple, t[0] string value, t[1] image index
+                - string or unicode value, image cleared
+        
+        Returns:
+            return code
+                - >0 : okay 
+                - =0 : okay nop
+                - <0 : error
         """
         try:
             if self.IsMainThread()==False:
@@ -163,9 +180,9 @@ class ldmWidList(ldmWidCore):
                 self.wid.SetItemData(idx,i)
                 return 0
             t=type(v)
-            if t==typesTupleType:
+            if t==ldmTypes.TupleType:
                 self.wid.SetStringItem(idx,i,v[0],v[1])
-            elif t==typesIntType:
+            elif t==ldmTypes.IntType:
                 self.wid.SetStringItem(idx,i,u'',v)
             else:
                 self.wid.SetStringItem(idx,i,v,-1)
@@ -174,13 +191,22 @@ class ldmWidList(ldmWidCore):
             self.logTB()
     def GetItemTup(self,idx,i):
         """get item value
-        ### parameter
-            idx     ... row index
-            i       ... column
-                    -1  ... data
-                    -3  ... data key
-                    <0  ... None
-                    >=0 ... column value as tuple, string and image index
+        
+        Args:
+            idx (int): row index
+            i (int): column
+                - -1  ... data
+                - -3  ... data key
+                - <0  ... None
+                - >=0 ... column value as tuple, string and image index
+        
+        Returns:
+            obj or tuple
+                item text
+
+                item image identifier
+
+
         """
         try:
             if self.IsMainThread()==False:
@@ -200,6 +226,19 @@ class ldmWidList(ldmWidCore):
         except:
             self.logTB()
     def GetItemStr(self,idx,i):
+        """get item string
+
+        Args:
+            idx (int): index
+            i (int): column
+                - -1  ... data
+                - -3  ... data key
+                - <0  ... None
+                - >=0 ... column value as tuple, string and image index
+
+        Returns:
+            obj or item text
+        """
         try:
             if self.IsMainThread()==False:
                 return None
@@ -218,6 +257,9 @@ class ldmWidList(ldmWidCore):
             self.logTB()
     def GetCount(self):
         """get row count
+
+        Returns:
+            int: item count
         """
         try:
             if self.IsMainThread()==False:
@@ -227,10 +269,11 @@ class ldmWidList(ldmWidCore):
             self.logTB()
     def __add_data__(self,data,i=0):
         """add data to cache
-        ### parameter
-            data    ... object to cache
-            i       ... key
-                    0   ... use attribute iDat
+        
+        Args:
+            data (obj): object to cache
+            i (int): key
+                - 0   ... use attribute iDat
         """
         try:
             if i==0:
@@ -243,10 +286,11 @@ class ldmWidList(ldmWidCore):
         return -1
     def SetDictMap(self,lMap):
         """set MAP property to be used item set by dictionary 
-        ### parameter
-            lMap    ... mapping list of tuples keys to column number
-                key 0   ... bitmap index (integer) or name (string)
-                key -1  ... data to be cached and referenced to list item
+        
+        Args:
+            lMap (list): mapping list of tuples keys to column number
+                - key 0 : bitmap index (integer) or name (string)
+                - key -1 : data to be cached and referenced to list item
         """
         try:
             bDbg=self.GetVerboseDbg(0)
@@ -257,19 +301,20 @@ class ldmWidList(ldmWidCore):
             self.logTB()
     def __setItemDict__(self,lst,idx,d):
         """set item by dictionary defined by property MAP
-        ### parameter
-            lst     ... widget
-            idx     ... row
-            d       ... dictionary values, property MAP used
+        
+        Args:
+            lst (wid): widget
+            idx (int): row
+            d (dict): dictionary values, property MAP used
         """
         #print tr.GetItemText(ti,0)
         for s,i in self.MAP:
             if s in d:
                 v=d[s]
                 t=type(v)
-                if t==typesTupleType:
+                if t==ldmTypes.TupleType:
                     lst.SetStringItem(idx,i,v[0],v[1])
-                elif t==typesIntType:
+                elif t==ldmTypes.IntType:
                     lst.SetStringItem(idx,i,u'',v)
                 else:
                     lst.SetStringItem(idx,i,v,-1)
@@ -278,10 +323,10 @@ class ldmWidList(ldmWidCore):
             img=d[0]
             bSkipImg=True
             t=type(img)
-            if t==typesIntType:
+            if t==ldmTypes.IntType:
                 self._it.SetImage(img)
                 bSkipImg=False
-            elif t==typesStringType:
+            elif t==ldmTypes.StringType:
                 if self._dImg is not None:
                     self._it.SetImage(self._dImg[img])
                     bSkipImg=False
@@ -298,10 +343,11 @@ class ldmWidList(ldmWidCore):
         #    self.__setValue__(tr,ti,d[-2])
     def __setItemLst__(self,lst,idx,l):
         """set item by list
-        ### parameter
-            lst     ... widget
-            idx     ... row
-            l       ... list values, data and column values
+        
+        Args:
+            lst (wid): widget
+            idx (int): row
+            l (list): list values, data and column values
         """
         try:
             if l[0] is not None:
@@ -311,9 +357,9 @@ class ldmWidList(ldmWidCore):
             i=0
             for v in l[1]:
                 t=type(v)
-                if t==typesTupleType:
+                if t==ldmTypes.TupleType:
                     lst.SetItem(idx,i,v[1]) #v[0],
-                elif t==typesIntType:
+                elif t==ldmTypes.IntType:
                     lst.SetItem(idx,i,u'')# v is image
                 else:
                     lst.SetItem(idx,i,v)
@@ -324,29 +370,34 @@ class ldmWidList(ldmWidCore):
                     l[0],l[1]))
     def __setItemTup__(self,tr,ti,t):
         """
-        ### parameter
+        Args:
+            tr (wid): widget
+            ti (wid): tree item
+            t (tuple): tuple
         """
         pass
     def __setItem__(self,lst,idx,val):
-        """set item, various types are handled
-        ### parameter
-            lst     ... widget
-            idx     ... row
-            val     ... values, dictionary or list
+        """set item, various types. are handled
+        
+        Args:
+            lst (wid): widget
+            idx (int): row
+            val (obj): values, dictionary or list
         """
         t=type(val)
-        if t==typesDictType:
+        if t==ldmTypes.DictType:
             self.__setItemDict__(lst,idx,val)
-        elif t==typesListType:
+        elif t==ldmTypes.ListType:
             self.__setItemLst__(lst,idx,val)
-        elif t==typesTupleType:
+        elif t==ldmTypes.TupleType:
             self.__setItemTup__(lst,idx,val)
     def __setValue__(self,lst,l,idx=-1):
         """set value
-        ### parameter
-            lst     ... widget
-            l       ... list of values, dictionary or list
-            idx     ... row
+        
+        Args:
+            lst (wid): widget
+            l (list): list of values, dictionary or list
+            idx (int): row
         """
         if idx<0:
             idx=0
@@ -360,18 +411,26 @@ class ldmWidList(ldmWidCore):
         return idx-1
     def __getValue__(self,lst,idx,lMap,l):
         """get item value
-        ### parameter
-            lst     ... widget
-            idx     ... row
-            lMap    ... list of columns to get
-                None, delivers [-2]
-                >=0 ... text of column
-                -1  ... cached data
-                -2  ... index
-                -3  ... cache key
-            l       ... list of values to return
+        
+        Args:
+            lst (wid): widget
+            idx (int): row
+            lMap (list): list of columns to get
+                - None, delivers [-2]
+                - >=0 ... text of column
+                - -1  ... cached data
+                - -2  ... index
+                - -3  ... cache key
+            l (list): list of values to return
         """
         def getVal(lst,idx,i):
+            """
+
+            Args:
+                lst (wid): widget
+                idx (int): index
+                i (int): column
+            """
             if i==-1:
                 i=lst.GetItemData(idx)
                 if i>0:
@@ -390,27 +449,30 @@ class ldmWidList(ldmWidCore):
             l.append([getVal(lst,idx,i) for i in lMap])
     def __getValueData__(self,lst,idx,l):
         """get value data
-        ### parameter
-            lst     ... widget
-            idx     ... row
-            l       ... list of values to return
+        
+        Args:
+            lst (wid): widget
+            idx (int): row
+            l (list): list of values to return
         """
         i=lst.GetItemData(idx)
         if i>0:
             l.append(self.dDat.get(i,None))
     def __insert__(self,lst,l,idx=-1):
         """insert
-        ### parameter
-            lst     ... widget
-            l       ... list of data and values to insert
-            idx     ... row
-                -1  ... insert at the end
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
-            -1  ... exception
-            -3  ... l is None
+        
+        Args:
+            lst (wid): widget
+            l (list): list of data and values to insert
+            idx (int): row
+                - -1 : insert at the end
+        
+        Returns:
+            - >0 : okay processing done
+            - =0 : okay nop
+            - <0 : error
+            - -1 : exception
+            - -3 : l is None
         """
         try:
             if l is None:
@@ -432,17 +494,20 @@ class ldmWidList(ldmWidCore):
         return -1
     def Insert(self,l,idx=-1):
         """insert
-        ### parameter
-            l       ... list of data and values to insert
-            idx     ... row
-                -1  ... insert at the end
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
-            -1  ... exception
-            -2  ... not called from main thread
-            -3  ... l is None
+        
+        Args:
+            l (wid): list of data and values to insert
+            idx (int): row
+                - -1 : insert at the end
+        
+        Returns:
+            return code
+              - >0 : okay processing done
+              - =0 : okay nop
+              - <0 : error
+              - -1 : exception
+              - -2 : not called from main thread
+              - -3 : l is None
         """
         try:
             bDbg=self.GetVerboseDbg(0)
@@ -457,19 +522,22 @@ class ldmWidList(ldmWidCore):
         return -1
     def SetValue(self,l,idx=-1):
         """set value
-        ### parameter
-            l       ... list of data and values to set
-            idx     ... row
-                >=0 ... item index to start set, in case more
+        
+        Args:
+            l (wid): list of data and values to set
+            idx (int): row
+                - >=0 : item index to start set, in case more
                         items are delivered to set, 
-                -1  ... clear items
-        ### return
-            >0  ... okay processing done
-            =0  ... okay nop
-            <0  ... error
-            -1  ... exception
-            -2  ... not called from main thread
-            -3  ... l is None
+                - -1 : clear items
+        
+        Returns:
+            return code
+                - >0 : okay processing done
+                - =0 : okay nop
+                - <0 : error
+                - -1 : exception
+                - -2 : not called from main thread
+                - -3 : l is None
         """
         try:
             bDbg=self.GetVerboseDbg(0)
@@ -492,13 +560,14 @@ class ldmWidList(ldmWidCore):
         return -1
     def GetValue(self,lMap=None,idx=None):
         """get value
-        ### parameter
-            lMap    ... list of columns to get
-                None .. cached data
-                >=0 ... text of column
-                -1  ... cached data
-                -2  ... index
-                -3  ... cache key
+        
+        Args:
+            lMap (list): list of columns to get
+                - None: cached data
+                - >=0 : text of column
+                - -1  : cached data
+                - -2  : index
+                - -3  : cache key
             idx     ... row
         """
         try:
@@ -533,16 +602,17 @@ class ldmWidList(ldmWidCore):
         return None
     def PrcFct(self,idx,bDbg,fct,*args,**kwargs):
         """process function on item
-        ### parameter
-            idx     ... index
-            bDbg    ... debugging flag
-            fct     ... callable applied on each item in addition
+        
+        Args:
+            idx (int): index
+            bDbg (bool): debugging flag
+            fct (callable): callable applied on each item in addition
                         to args and kwargs following values are passed
-                iOfs .. current processing number starting at 0
-                iCnt .. total number of calls
-                iIdx .. item index
-            args    ... arguments
-            kwargs  ... keyword arguments
+                - iOfs : current processing number starting at 0
+                - iCnt : total number of calls
+                - iIdx : item index
+            args (list): arguments
+            kwargs (dict): keyword arguments
         """
         try:
             bDbg=self.GetVerboseDbg(0)
@@ -575,11 +645,12 @@ class ldmWidList(ldmWidCore):
             return -1
     def __setState__(self,lst,l,bFlag,iState):
         """set state
-        ### parameter
-            lst     ... widget
-            l       ... list of index
-            bFlag   ... flag
-            iState  ... item status
+        
+        Args:
+            lst (wid): widget
+            l (list): list of index
+            bFlag (bool): flag
+            iState (int): item status
         """
         try:
             iCnt=lst.GetItemCount()
@@ -615,25 +686,28 @@ class ldmWidList(ldmWidCore):
         return -1
     def __setSelected__(self,lst,l,bFlag):
         """set selected status
-        ### parameter
-            lst     ... widget
-            l       ... list of index
-            bFlag   ... flag
+        
+        Args:
+            lst (wid): widget
+            l (list): list of index
+            bFlag (bool): flag
         """
         return self.__setState__(lst,l,bFlag,wx.LIST_STATE_SELECTED)
     def __getState__(self,lst,lMap,l,iState):
         """get item values with state set
-        ### parameter
-            lst     ... widget
-            lMap    ... list of columns to get
-                None, delivers [-2]
-                >=0 ... text of column
-                -1  ... cached data
-                -2  ... index
-                -3  ... cache key
-            l       ... list of values to return
-            iState  ... state
-        ### return
+        
+        Args:
+            lst (wid): widget
+            lMap (list): list of columns to get
+                - None: delivers [-2]
+                - >=0 : text of column
+                - -1  : cached data
+                - -2  : index
+                - -3  : cache key
+            l (list): list of values to return
+            iState (int): state
+        
+        Returns:
             number of items matching state
         """
         try:
@@ -649,16 +723,18 @@ class ldmWidList(ldmWidCore):
         return -1
     def __getSelected__(self,lst,lMap,l):
         """get selected item values
-        ### parameter
-            lst     ... widget
-            lMap    ... list of columns to get
-                None, delivers [-2]
-                >=0 ... text of column
-                -1  ... cached data
-                -2  ... index
-                -3  ... cache key
-            l       ... list of values to return
-        ### return
+        
+        Args:
+            lst (wid): widget
+            lMap (list): list of columns to get
+                - None: delivers [-2]
+                - >=0 : text of column
+                - -1  : cached data
+                - -2  : index
+                - -3  : cache key
+            l (list): list of values to return
+        
+        Returns:
             number of items matching state
         """
         return self.__getState__(lst,lMap,l,wx.LIST_STATE_SELECTED)
@@ -690,13 +766,13 @@ class ldmWidList(ldmWidCore):
                     self.__getSelected__(lst,None,lSel)
                     self.__setSelected__(lst,lSel,bFlag=False)
             t=type(l)
-            if t==typesDictType:
+            if t==ldmTypes.DictType:
                 if lMapChk is None:
                     lKeys=l.keys()
                     lMapChk=[]
                     ll=[]
                     for sK in lKeys:
-                        if type(sK)==typesIntType:
+                        if type(sK)==ldmTypes.IntType:
                             lMapChk.append(sK)
                             ll.append(l[sK])
                         else:
@@ -725,9 +801,9 @@ class ldmWidList(ldmWidCore):
                 if iCntChk==1:
                     if iCnt>0:
                         t=type(l[0])
-                        if t==typesListType:
+                        if t==ldmTypes.ListType:
                             pass
-                        elif t==typesListType:
+                        elif t==ldmTypes.ListType:
                             pass
                         else:   # 20150118 wro:values need to be list,
                                 #       convert l from [1,2] to l=[[1],[2]]
@@ -760,14 +836,16 @@ class ldmWidList(ldmWidCore):
         return -1
     def GetSelected(self,lMap=None):
         """get selected elements
-        ### parameter
-            lMap    ... list of column offsets to retrieve
+        
+        Args:
+            lMap (list): list of column offsets to retrieve
                         None will deliver [-2,-1]
-                -3  ... cache key
-                -2  ... index
-                -1  ... cached data
-                >=0 ... text of column
-        ### return
+                - -3  : cache key
+                - -2  : index
+                - -1  : cached data
+                - >=0 : text of column
+        
+        Returns:
             list of selected items, holding mapped values
         """
         try:
@@ -783,8 +861,9 @@ class ldmWidList(ldmWidCore):
         return None
     def DelIdx(self,iIdx):
         """delete index
-        ### parameter
-            iIdx    ... item to delete form list
+        
+        Args:
+            iIdx (int): item to delete form list
         """
         try:
             self.wid.DeleteItem(iIdx)
@@ -792,7 +871,6 @@ class ldmWidList(ldmWidCore):
             self.logTB()
     def DelSelected(self):
         """delete selected
-        ### parameter
         """
         try:
             lSel=self.GetSelected([-2,-1])
