@@ -15,7 +15,35 @@ from lindworm.ldmWidCore import ldmWidCore
 import lindworm.ldmGui as ldmGui
 
 class ldmWidPanel(ldmWidCore):
+    """wx panel widget abstraction, allows to add widgets
+    by simply define a list of definition tuples at constructor in argument lWid.
+    lWid=[
+        (sCls, sName, sVal, sLnk),  # add widget
+        (None),                     # add spacer wth size 5
+    ],
+
+    supported sCls identifiers:
+        'lbl'   ... label, static text
+        'gag'   ... gauge, sVal = max value; should be integer
+        'txt'   ... text field, sVal text to set
+        'txtLn' ... multiline text field, sVal text to set
+        'txtRd' ... read only text field, sVal text to set
+        'spn'   ... spin widget sVal= (val,(min,max))
+        'lst'   ... list control
+        'chc'   ... choice widget sVal=(val,[choice0,choice1, ... ,choiceN])
+        'cb'    ... command button, sVal button label
+        'cbBmp' ... bitmap command button, sVal defines bitmap to use
+        'cbd'   ... command button browse directory (folder), sVal title
+        'cbf'   ... command button browse file, sVal title, sLnk link
+    """
     def getEvtDat(self,evt):
+        """get event data
+        data can be retrieved by id, which is already property of wx event object
+        data can therefore by anything, and does not add to object size
+        
+        Args:
+            evt (wid): wx event
+        """
         try:
             # +++++ beg:
             iRet=0
@@ -31,6 +59,8 @@ class ldmWidPanel(ldmWidCore):
             self.logTB()
             return None
     def getFileOpen(self):
+        """prepared for future implementation
+        """
         try:
             # +++++ beg:
             iRet=0
@@ -40,6 +70,11 @@ class ldmWidPanel(ldmWidCore):
             self.logTB()
             return -1
     def prcCmd(self,sCmd):
+        """process command
+        
+        Args:
+            sCmd (str): command to be processed
+        """
         try:
             # +++++ beg:
             self.logDbg('ldmWidPanel::prcCmd sCmd:%r',sCmd)
@@ -49,6 +84,11 @@ class ldmWidPanel(ldmWidCore):
             self.logTB()
             return -1
     def OnCmd(self,evt):
+        """GUI event handler
+
+        Args:
+            evt (wid): event object
+        """
         evt.Skip()
         try:
             # +++++ beg:initialize
@@ -60,6 +100,11 @@ class ldmWidPanel(ldmWidCore):
         except:
             self.logTB()
     def OnBwsDN(self,evt):
+        """GUI event handler open dialog to brose for file system folder
+
+        Args:
+            evt (wid): event object
+        """
         evt.Skip()
         try:
             # +++++ beg:initialize
@@ -86,6 +131,11 @@ class ldmWidPanel(ldmWidCore):
         except:
             self.logTB()
     def OnBwsFN(self,evt):
+        """GUI event handler open dialog to brose for file.
+
+        Args:
+            evt (wid): event object
+        """
         evt.Skip()
         try:
             # +++++ beg:initialize
@@ -144,6 +194,17 @@ class ldmWidPanel(ldmWidCore):
         except:
             self.logTB()
     def __getRegDat__(self,iId):
+        """get registered data by id;
+        id equals widget id used on create
+        each widget can have 1 data objects assigned
+        
+        Args:
+            iID (int): identifier
+        
+        Returns
+            obj: oDat , data object
+               - None ... object not found
+        """
         try:
             # +++++ beg:
             if iId in self.dIdDat:
@@ -156,6 +217,14 @@ class ldmWidPanel(ldmWidCore):
             self.logTB()
             return None
     def __setRegDat__(self,oDat):
+        """register object to widget,
+        each widget can have 1 data object assigned,
+        each widget utilizing GUI event handler should call method.
+        after object is registered self.iId is incremented. 
+        
+        Args:
+            oDat (obj): data object to register
+        """
         try:
             # +++++ beg:
             self.logDbg('iId:%d oDat:%r',self.iId,oDat)
@@ -165,6 +234,11 @@ class ldmWidPanel(ldmWidCore):
         except:
             self.logTB()
     def __bldWid__(self,tDef):
+        """build widget
+        
+        Args:
+            tDef (tuple): definition 
+        """
         try:
             # +++++ beg:
             iExp=0
@@ -186,7 +260,7 @@ class ldmWidPanel(ldmWidCore):
             if sVal is None:
                 sVal=''
             # ----- end:
-            # +++++ beg:
+            # +++++ beg:create widget
             wPar=self.GetWid()
             if sCls=='lbl':
                 wSub=wx.StaticText(wPar, wx.ID_ANY, sVal)
@@ -247,22 +321,37 @@ class ldmWidPanel(ldmWidCore):
                 wPar.Bind(wx.EVT_BUTTON, self.OnBwsFN, wSub)
             else:
                 wSub=None
-            # ----- end:
-            # +++++ beg:
+            # ----- end:create widget
+            # +++++ beg:set widget as attribute
             if wSub is not None:
                 if sName is not None:
                     if getattr(self,sName,None) is None:
                         setattr(self,sName,wSub)
                     else:
                         self.logErr('sName:%s already used'%(sName))
-            # ----- end:
+            # ----- end:set widget as attribute
             return wSub,iExp
         except:
             self.logTB()
             return None,0
     def __initCls__(self,**kwargs):
+        """class initializer, set self.clsWid to wxPython class
+
+        Args:
+            kwargs (dict): flexible keyword arguments
+        """
         self.clsWid=wx.Panel
     def __initWid__(self,**kwargs):
+        """initialize widget
+        create container widget self.clsWid (provided by __initCls__),
+        create sizer object by calling method __initSizer__ and
+        add widgets defined by kwargs lWid, list of tuples to be fed
+        into __bldWid__, sub widget is added to sizer object.
+        
+        Args:
+            lWid (list): list of tuples to define sub widgets
+
+        """
         try:
             # +++++ beg:
             self.iId=1000
@@ -289,6 +378,12 @@ class ldmWidPanel(ldmWidCore):
         except:
             self.logTB()
     def __initSizer__(self,**kwargs):
+        """initialize sizer, horizontal box sizer is used
+        to respond to widget resizing.
+        
+        Args:
+            kwargs (dict): keyword arguments
+        """
         try:
             bDbg=self.GetVerboseDbg(20)
             if bDbg:
@@ -297,6 +392,13 @@ class ldmWidPanel(ldmWidCore):
         except:
             self.logTB()
     def __addSizerWid__(self,tDef,wSub,iExp):
+        """add sub widget to sizer object
+        
+        Args:
+            tDef (tuple): widget definition tuple
+            wSub (wid): wx widget
+            iExp (int): widget expand directive for sizer
+        """
         try:
             iRet=0
             if wSub is None:
@@ -309,6 +411,13 @@ class ldmWidPanel(ldmWidCore):
         except:
             self.logTB()
     def __initLayout__(self,**kwargs):
+        """initialize layout
+        finally sizer object has to be assigned to widget.
+        method is called by base class.
+        
+        Args:
+            kwargs (dict): keyword arguments
+        """
         try:
             bDbg=self.GetVerboseDbg(20)
             if bDbg:
@@ -322,6 +431,12 @@ class ldmWidPanel(ldmWidCore):
 
 class ldmWidPanelVert(ldmWidPanel):
     def __initSizer__(self,**kwargs):
+        """initialize sizer, vertical box sizer is used
+        to respond to widget resizing.
+        
+        Args:
+            kwargs (dict): keyword arguments
+        """
         try:
             bDbg=self.GetVerboseDbg(20)
             if bDbg:
@@ -332,6 +447,14 @@ class ldmWidPanelVert(ldmWidPanel):
 
 class ldmWidPanelFlxGrd(ldmWidPanel):
     def __initSizer__(self,**kwargs):
+        """initialize sizer, flexible grid sizer is used
+        to respond to widget resizing.
+        
+        Args:
+            kwargs (dict): key word arguments
+                - iRow : number of rows
+                - iCol : number of columns
+        """
         try:
             bDbg=self.GetVerboseDbg(20)
             if bDbg:
@@ -346,6 +469,15 @@ class ldmWidPanelFlxGrd(ldmWidPanel):
         except:
             self.logTB()
     def __initLayout__(self,**kwargs):
+        """initialize layout
+        finally sizer object has to be assigned to widget.
+        method is called by base class.
+        
+        Args:
+            kwargs (dict): key word arguments
+                - lRow ,, list of growable rows
+                - lCol .. list of growable columns
+        """
         try:
             bDbg=self.GetVerboseDbg(20)
             if bDbg:
