@@ -21,11 +21,14 @@ iVerbose=0
 
 def logInit(sLogFN,sLogger='',iLevel=logging.DEBUG,iNameLen=6):
     """initialize logging
-    sLogFN      ... filename
-    sLogger     ... module log name
-    iLevel      ... detail level
-    iNameLen    ... module name length of formatting
-    return 
+    ### parameter
+        sLogFN      ... filename
+        sLogger     ... module log name
+        iLevel      ... detail level
+        iNameLen    ... module name length of formatting
+    ### return 
+        oLog        ... logging object
+                None .. something went wront
     """
     # +++++ beg:info
     global lngFileHandler
@@ -190,6 +193,9 @@ def log(iLv,sMsg,*args):
         logDbg(sMsg,*args)
 
 class ldmUtilLog:
+    """basic logging object should be inherited by complex objects, widgets
+    to ease use of logging package.
+    """
     def __init__(self,sLogger='',iLv=0,iLevel=None,iVerbose=0,sOrg=None,iIndent=2):
         """constructor
         ### parameter
@@ -229,22 +235,33 @@ class ldmUtilLog:
         else:
             self.sOrg=sLogger
     def rstDepth(self):
+        """reset depth
+        """
         self.iDepth=-1
         self.bldIndent()
     def setDepth(self,iDepth):
+        """set depth
+        """
         self.iDepth=iDepth
         self.bldIndent()
     def incDepth(self):
+        """increment depth
+        """
         if self.iDepth<0:
             self.iDepth=0
         self.iDepth+=1
         self.bldIndent()
     def decDepth(self):
+        """decrement depth
+        """
         self.iDepth-=1
         if self.iDepth<0:
             self.iDepth=0
         self.bldIndent()
     def bldIndent(self):
+        """build indention string to be added as prefix to log message
+        per depth (level) amount of iIdent spaces are added.
+        """
         if self.iDepth<=0:
             self.sIndent=None
         else:
@@ -340,10 +357,13 @@ class ldmUtilLog:
         else:
             self.logDbg(sMsg,*args)
     def logTB(self):
+        """log traceback, typical called in exception part
+        """
         self.oLog.error(traceback.format_exc())
     def GetVerbose(self,iVerbose=-1):
         """get verbose level 
         ### parameter
+            iVerbose    ... verbose level to check
         ### return
             True    ... object verbose >= iVerbose
             False   ... object verbose < iVerbose
